******************************************************************************
      subroutine backgr( nqh , chCard , ar1 )
      implicit none
*parse options for the BACKGROUND command
      integer nqh
      real ar1
      character chCard*80
*
      include "pi4.par"
      include "itrdim.par"
      include "HIonPot.par"
      include "limspc.par"
      include "range.com"
      include "spec.com"
      include "sptype.com"
      include "spnorm.com"
      include "radius.com"
      include "bounds.com"
      include "rdfalt.com"
      include "IOqq.com"
*
*     local variables
      logical lgEOL , lgMatch
      integer i
      real z , fread , fac , a , rlogl
*
*     check that stack of shape and luminosity specifications
*     is parallel, stop if not - this happens is background comes
*     BETWEEN another set of shape and luminosity commands
      if( nspec.ne.nqh ) then
        write(qq,'('' This command has come between a previous ''
     1  ,''ordered pair of continuum shape and luminosity commands.''/
     2  ,'' Reorder the commands to complete each continuum '',
     3  ''specification before starting another.'')')
        write(qq,'('' Sorry.'')')
        stop
      endif
*
*     diffuse x-ray background from Ostriker and Ikeuchi Ap.J.L 268, L63.
*     parameter on card is redshift, followed by optional J21 (ApJ 301, 522)
      nspec = nspec+1
      if( nspec.gt.limspc) then
        write(qq,'('' Too many continua entered; increase LIMSPC'')')
        stop
      endif
      chSpType(nspec) = 'POWER'
      slope(nspec) =  -1.
      cutoff(nspec,1) = 1e10
      cutoff(nspec,2) = 0.
*     now generate equivalent of luminosity command
*     enter phi(h), the number of h-ionizing photons/cm2
      nqh = nqh + 1 
      if( nqh.gt.limspc ) then
        write(qq,'('' Too many continua entered; increase LIMSPC'')')
        stop
      endif
      chRSpec(nqh) = 'SQCM'
      chSpNorm(nqh) = 'FLUX'
      i = 5
*
*     this will be the redshift
      z = fread( chCard , i , 76 , lgEOL )
      if( lgEOL ) then
        z = 0.
      endif
*     optional scale factor
      fac = fread( chCard , i , 76 , lgEOL )
      if( lgEOL ) fac = 1.0
*
*     this equation from Ostriker and Ikeuchi Ap.J.L 268, L63.
*     this should be J_nu into 4\pi sr
*     >>chng 96 july 23, from ostriker to vedel, et al mnras 271, 743.
      totpow(nqh) = log10( pi4 * fac * 1.e-21 /
     1 (1.+(5./(1.+z)) ** 4 )  )
*     this is at 1 ryd for H
*     range(nqh,1) = 1.
*chnage 96 dec 18, to H ioniz pot from 1 ryd
      range(nqh,1) = HIonPot
*
*     add fireball unless NO FIREBALL in
      if( .not.lgMatch( 'O FI', chCard ) ) then
        nspec = nspec+1
        nqh = nqh + 1 
        if( nqh.gt.limspc ) then
          write(qq,'('' Too many continua entered; increase LIMSPC'')')
          stop
        endif
*       put in a black body
        chSpType(nspec) = 'BLACK'
        slope(nspec) = 2.756 * ( 1. + z )
        cutoff(nspec,1) = 0.
        cutoff(nspec,2) = 0.
        chSpNorm(nqh) = 'LUMI'
        a = log10(slope(nspec))
        rlogl = log10( 2.99792e10 * 7.56464e-15) + 4.*a
        chRSpec(nqh) = 'SQCM'
        range(nqh,1) = emm
        range(nqh,2) = egamry
        totpow(nqh) = rlogl
      endif
*
*     set radius to very large value if not already set
      if( radius.eq.0. ) then
        ar1 = rdfalt
        radius = 10.**ar1
      endif
*
      end
