******************************************************************************
      subroutine beseq(cs12,cs13,cs23,tarray,a30)
      implicit none
*compute level populations and emissivity for Be-sequence ions
      real cs12,cs13,cs23,a30
      include "nta.par"
      real tarray(nta)
*
      include "ipLnArry.par"
      include "limelm.par"
      include "limLevelN.par"
      include "dcool.com"
      include "IonFracs.com"
      include "edsqte.com"
      include "p2ovp1.com"
      include "TePowers.com"
      include "PopLevls.com"
      include "IOqq.com"
      include "phycon.com"
*
*     local variables
      logical lgNegPop
      integer i , ner
      double precision zz(0:4,0:4)
      real boltz , excit , a20,c10,c20,c02,c01,aem,
     1 coolng , dest , c30 , c03,c21,c12,c31,c13,c32,c23,cs1u,
     1 AbunxIon , ri02 , ri20 , tot20
      real r10,r01,r02,r20,r30,r03, r12,r21,r13,r31,r23,r32,
     1 Enr01 , Enr10
      character chIonLbl*4 , chLab*4
*
*     function returns total emission in both components of line
*     destruction by background opacity computed and added to otslin field
*     here,
*     total cooling computed and added via coladd
*
*     finds population of four level Be-like atom
*     level 1 = ground, J=0
*     levels 2,3,4 are J=0,1,2, OF 3P.
*     levels 3-1 is the fast one, j=1 to ground j=0
*     cs1u is coll str to all J sub-levels of 3P; C.S. goes as 2J+1
*
*     beseq(cs12,cs13,cs23,tarray,a30,chLab)
*     xIonFracs(nelem,i) is density of ith ionization stage (cm^-3)
      AbunxIon = xIonFracs( int(tarray(ipLnNelem)) , 
     1  int(tarray(ipLnIonStg)) )
      chLab = chIonLbl( tarray )
      boltz = tarray(ipLnBolt) / te
*     low density cutoff to keep matrix happy
      if( AbunxIon.le.1e-20 .or. boltz.gt.30. ) then
*       put in pop since possible just too cool
        tarray(ipLnPopl) = AbunxIon
*     >>chng 96 sep 12, ipLnPopu had not been set before
        tarray(ipLnPopOpc) = AbunxIon
        tarray(ipLnPopu) = 0.
        tarray(ipLnInten) = 0.
        tarray(ipLnCool) = 0.
        tarray(ipLnNPhots) = 0.
        tarray(ipLnOTS) = 0.
        tarray(ipLnAovTOT) = 0.
        tarray(ipLnColovTOT) = 0.
        tarray(ipLnHeat) = 0.
*       level populations
        PopLevels(0) = AbunxIon
        PopLevels(1) = 0.
        PopLevels(2) = 0.
        PopLevels(3) = 0.
        DepLTELevels(0) = 1.
        DepLTELevels(1) = 0.
        DepLTELevels(2) = 0.
        DepLTELevels(3) = 0.
        p2ovp1 = 0.
        call coladd( chLab,int(tarray(ipLnWlAng)) ,0. )
*       now add zero to ots field
        call AddOTSLin( 0. , int(tarray(ipLnIpCont) ) ,1.0 )
        return
      endif
      excit = exp( -boltz )
      cs1u = tarray(ipLnCS)
*
*begin sanity checks
      if( tarray(ipLnGl) .ne. 1. .or. tarray(ipLnGu).ne.3. ) then
        write(qq,'('' BESEQ called with insane stat weights:'',
     1  2f5.0,1x,a4)') tarray(ipLnGl),tarray(ipLnGu),chLab
      endif
      if( cs1u.le.0. ) then
        write(qq,'('' BESEQ called with insane coll strength:'',
     1  1p,e10.2,1x,a4)') tarray(ipLnCS),chLab
      endif
*end sanity checks
*
*     incuded rates for fastest transition
      ri02 = tarray(ipLnPump)
*     back reaction has ratio of stat weights
      ri20 = tarray(ipLnPump) *1./3.
*
*     net rate out of level 3, with destruction
      a20 = tarray(ipLnAul) * ( tarray(ipLnEscP) + tarray(ipLnDesP) )
      tot20 = a20 + ri20
*
*     1/9 is ratio of level stat weight to term stat weight
      c10 = cs1u * cdsqte / 9.
      c01 = c10 * excit
      r01 = c01
      r10 = c10
*
*     stat weights canceled out here
      c20 = c10
      c02 = c01 * 3.
      r02 = c02 + ri02
      r20 = c20 + tot20
*
      c30 = c10
      c03 = c01 * 5.
      r30 = c30 + a30
      r03 = c03
*
      c21 = cs12 * cdsqte / 3.
      c12 = c21 * 3.
      r12 = c12
      r21 = c21
*
      c31 = cs13 * cdsqte / 5.
      c13 = c31 * 5.
      r31 = c31
      r13 = c13
*
      c32 = cs23 * cdsqte / 5.
      c23 = c32 * 1.667
      r32 = c32
      r23 = c23
*
*     set up matrix
      do i=0,3
*       first equation will be sum to abund
        zz(0,i) = 1.
        zz(i,4) = 0.
      end do
*
*     zz(0,4) = AbunxIon
      zz(0,4) = 1.
*
*     ground level 0 is implicit
*     level 1 balance equation
      zz(1,0) = -r01
      zz(1,1) = r10 + r12 + r13
      zz(1,2) = -r21
      zz(1,3) = -r31
*     level 2 balance equation
      zz(2,0) = -r02
      zz(2,1) = -r12
      zz(2,2) = r20 + r21 + r23
      zz(2,3) = -r32
*     level 3 balance equation
      zz(3,0) = -r03
      zz(3,1) = -r13
      zz(3,2) = -r23
      zz(3,3) = r30+r31+r32
      call matin1(zz,5,4,1,ner)
      if( ner.ne.0 ) then
        write(qq,'('' beseq matrix error'')')
        stop
      endif
*
      lgNegPop = .false.
      do i=0,3
        PopLevels(i) = zz(i,4) * AbunxIon
        if( PopLevels(i).lt.0. ) lgNegPop = .true.
      end do
*
      if(lgNegPop) then
        write(qq,*) ' beseq finds non-positive pop,=',
     1  (PopLevels(i),i=0,3),chLab
        write(qq,*)' te=',te,' total abund=',AbunxIon,' boltz=',boltz
        stop
      endif
*
      p2ovp1 = PopLevels(2) / PopLevels(0) / 3.
      DepLTELevels(0) = 1.
      DepLTELevels(1) = (PopLevels(1)/PopLevels(0))/excit
      DepLTELevels(2) = (PopLevels(2)/PopLevels(0))/(excit*3.)
      DepLTELevels(3) = (PopLevels(3)/PopLevels(0))/(excit*5.)
*
*     compute ratio Aul/(Aul+Cul)
      aem = tarray(ipLnAul) * tarray(ipLnEscP)
      tarray(ipLnAovTOT) = aem / (aem+c20)
*
      tarray(ipLnColovTOT) = c02 / r02
*
      tarray(ipLnPopl) = AbunxIon
*     >>chng 96 sep 12, ipLnPopu had not been set before
      tarray(ipLnPopu) = PopLevels(2)
      tarray(ipLnPopOpc) = AbunxIon - PopLevels(2)*1./3.
*     this will be escaping part of line
*     number of escaping line photons, used elsewhere for outward beam
      tarray(ipLnNPhots) = PopLevels(2)*tarray(ipLnAul)*tarray(ipLnEscP)
      tarray(ipLnInten) = tarray(ipLnNPhots) * tarray(ipLnEnrErg)
*
*     follow is total cooling due to this line, inclues destroyed part
*
*     following are correct heat exchange, if will mix to get correct deriv
      Enr01 = PopLevels(0)*(c01+c02+c03)*tarray(ipLnEnrErg)
      Enr10 = (PopLevels(1)*c10+ PopLevels(2)*c20+
     1 PopLevels(3)*c30 ) *tarray(ipLnEnrErg)
*
*     net cooling due to excit minus part of de-excit
      tarray(ipLnCool) = Enr01 - Enr10*tarray(ipLnColovTOT)
*     net heating is remainder
      tarray(ipLnHeat) = Enr10*(1.-tarray(ipLnColovTOT))
*
      coolng = tarray(ipLnCool) 
      call coladd( chLab,int(tarray(ipLnWlAng)) , coolng )
*
*     derivative of cooling function
      dCooldT = dCooldT + coolng*( tarray(ipLnBolt)*tsq1 - halfte )
*
*     destroyed part of line
      dest = PopLevels(2) * tarray(ipLnAul) * tarray(ipLnDesP)
      tarray(ipLnOTS) = dest
*
*     now add to ots field
      call AddOTSLin( dest , int(tarray(ipLnIpCont) ) ,1.0 )
*
      end
