******************************************************************************
      subroutine CheckAge
      implicit none
*check various timescales after calculation complete to confirm time steady OK
      include "nzlim.par"
      include "itrdim.par"
      include "bltzman.par"
      include "CloudAge.com"
      include "IOqq.com"
      include "timesc.com"
      include "struc.com"
      include "ZoneCnt.com"
      include "sound.com"
      include "PrnAges.com"
      include "AgeMole.com"
      include "cpres.com"
      character chLine*132
*
*     local variables
      integer i
      real threc , tlong , tsound
*
*     cloud age of zero means that age command turned off
*     negative cloud age means was not set
*
*     remember longest timescale
      tlong = 0.
*     thermal equilibrium timescale
      ttherm = 0.
*     >>chng 97 may 6, may not be data for last zone if unusual exit
      do i=1,max(1,nzone-1)
        ttherm = max( ttherm,
     1  pdenstr(i)*Boltzmann*1.5*testr(i)/heatstr(i) )
      end do
*
      tlong = max( tlong , ttherm )
      if( lgPrnAges ) then
        write(chLine,'(''   AGE: longest thermal '',
     1  ''timescale='',1p,e10.2,''s.'')') ttherm
        call notein( chLine )
      endif
      if( CloudAgeSet.gt.0. .and. ttherm.gt.CloudAgeSet ) then
        write(chLine,'('' C-AGE: Thermal equilibrium '',
     1  ''timescale longer than age, ='',1P,E10.2,''s'')') ttherm
        call caunin( chLine )
      endif
*
*     check soundt travel time if constant pressure
      if( chCPres.eq.'CPRE' ) then
        tsound = sound
        if( lgPrnAges ) then
          write(chLine,'(''   AGE: sound travel '',
     1    ''time='',1p,e10.2,''s.'')') tsound
          call notein( chLine )
        endif
        if( CloudAgeSet.gt.0. .and. tsound.gt.CloudAgeSet ) then
          write(chLine,'('' C-AGE: Sound travel time '',
     1    ''longer than age in constant pressure model ='',1P,E10.2,
     2    ''s'')') ttherm
          call caunin( chLine )
        endif
      else
*       do not check if not constant pressure
        tsound = 0.
      endif
      tlong = max( tlong , tsound )
*
*     molecule formation timescale
      tlong = max( tlong , BigH2MoleForm , BigCOMoleForm )
*     >>chng 97 jan 3, don't print if zero
      if( lgPrnAges .and. BigH2MoleForm.gt.0. ) then
        write(chLine,'(''   AGE: longest H2 formation '',
     1  ''timescale='',1p,e10.2,''s.'')') BigH2MoleForm
        call notein( chLine )
      endif
      if( CloudAgeSet.gt.0. .and. BigH2MoleForm.gt.CloudAgeSet ) then
        write(chLine,'('' C-AGE: H2 formation '',
     1  ''timescale longer than age, ='',1P,E10.2,''s'')') BigH2MoleForm
        call caunin( chLine )
      endif
* 
      if( lgPrnAges .and. BigCOMoleForm.gt.0. ) then
        write(chLine,'(''   AGE: longest CO formation '',
     1  ''timescale='',1p,e10.2,''s.'')') BigCOMoleForm
        call notein( chLine )
      endif
      if( CloudAgeSet.gt.0. .and. BigCOMoleForm.gt.CloudAgeSet ) then
        write(chLine,'('' C-AGE: CO formation '',
     1  ''timescale longer than age, ='',1P,E10.2,''s'')') BigCOMoleForm
        call caunin( chLine )
      endif
*
*     hydrogen recombination timescale
      threc = 0.
      do i=1,max(1,nzone-1)
        threc = max( threc,
     1  1./(ednstr(i)*2.90e-10*testr(i)**(-0.77)) )
      end do
*
      tlong = max( tlong , threc )
      if( lgPrnAges ) then
        write(chLine,'(''   AGE: longest H recombination '',
     1  ''timescale='',1p,e10.2,''s.'')') threc
        call notein( chLine )
      endif
      if( CloudAgeSet.gt.0. .and. threc.gt.CloudAgeSet ) then
        write(chLine,'('' C-AGE: Hydrogen recombination '',
     1  ''timescale longer than age, ='',1P,E10.2,''s'')') threc
        call caunin( chLine )
      endif
*
      if( CloudAgeSet.lt.0. ) then
*       CloudAgeSet initially set to -1, if still the case then age not set
        if( tlong.lt.3600. ) then
*         less than one day, give only seconds
          write(chLine,'(''  !AGE: Cloud age was not set.  Longest '',
     1    ''timescale was'',1p,e9.2,''s.'')') tlong
          call bangin( chLine )
        else if( tlong.lt.8.64e4 ) then
*         less than one day, give seconds and hours
          write(chLine,'(''  !AGE: Cloud age was not set.  Longest '',
     1    ''timescale was '',1p,e8.2,''s = '',e8.2,'' hours.'')') tlong,
     2    tlong/3600.
          call bangin( chLine )
        else if( tlong.lt.3e7/12. ) then
*         less than one month, give seconds and days
          write(chLine,'(''  !AGE: Cloud age was not set.  Longest '',
     1    ''timescale was '',1p,e8.2,''s = '',e8.2,'' days.'')') tlong,
     2    tlong/86400.
          call bangin( chLine )
        else if( tlong.lt.3e7 ) then
*         less than one year, give seconds and months
          write(chLine,'(''  !AGE: Cloud age was not set.  Longest '',
     1    ''timescale was '',1p,e8.2,''s = '',e8.2,'' months.'')')tlong,
     2    tlong/3.15569e7*12.
          call bangin( chLine )
        else
*         more than one year, give seconds and years
          write(chLine,'(''  !AGE: Cloud age was not set.  Longest '',
     1    ''timescale was '',1p,e8.2,''s = '',e8.2,'' years.'')') tlong,
     2    tlong/3.15569e7
          call bangin( chLine )
        endif
      else
*       age set, and passed tests, still say longest
        if( tlong.lt.3e7 ) then
*         less than one year, give only seconds
          write(chLine,'(''   AGE: Cloud age was'',1p,e9.2,
     1    ''s, Longest '',''timescale was '',1p,e8.2,''s.'')')
     1    CloudAgeSet,tlong
          call notein( chLine )
        else
*         more than one year, give seconds and years
          write(chLine,'(''  !AGE: Cloud age was '',1p,e9.2,
     1    ''s.  Longest timescale was'',e9.2,''s = '',e8.2,'' years.''
     2    )') CloudAgeSet,tlong, tlong/3.15569e7
          call bangin( chLine )
        endif
      endif
*
      end
