******************************************************************************
      subroutine cloudy
      implicit none
*the main routine, this IS Cloudy
      include "IterCnt.com"
      include "itrdim.par"
      include "ZoneCnt.com"
      include "noexec.com"
      include "he2tau.com"
*
*     local variables
      logical lgEndFun , lgOK
*
*     this is the main routine to drive the modules that compute a model
*     when cloudy is used as a stand-alone program 
*     the main program (PROGRAM MAIN) calls CDINIT then CDDRIV
*     this sub is called by CDDRIV which returns upon exiting
*
*     this routine uses the following variables:
*
*     NZONE 
*     this is the zone number, and is incremented here
*     logical function lgEndFun returns a true condition if NZONE reaches
*     NEND(ITER), the limit to the number of zones in this iteration
*     NZONE is totally controlled in this subroutine
*
*     ITER 
*     this is the iteration number, it is 1 for the first iteration
*     and is incremented in this subroutine at the end of each iteration
*
*     itermx
*     this is the limiit to the number of iterations, and is entered
*     by the user
*     This routine returns when ITER > ITERMX
*
*     zero out some variables that can't be in big block
      call zero
*     NZONE is zero while initial search for conditions takes place
      nzone = 0
*     interpret input data
      call readr
*     ITER is iteration number
      iter = 1
*     fix pointers to ionization edges and frequency array
*     this routine has internal check for whether ever called before,
*     if only retuns if this is a later call of code
      call SetPoint
*     fix abundances of elements
      call abnset
*     find normalization factors for the continua
      call conorm
*     set continuum
      call SetCon( lgOK )
*     print header
      call prhead
*     this is an option to stop after printing header only
      if( lgNoExec ) return
      if( .not.lgOK ) then
        call BadStart
        return
      endif
*     set upper and lower stages of ionization of heavies
      call nsset
*     guess some outward optical depths
      call tauout
      call opac0
      call tfirst( lgOK )
*     punt if initial conditions outside range of code
      if( .not.lgOK ) then
        call BadStart
        return
      endif
      call FirstDR
      call NextDR
      call zonsrt('init')
      call plot('FIRST')
*     will not trip on following test - will return in mid-loop
      do while( iter.le. itermx+10 )
        call startr
        nzone = 0
*       main loop to drive model
*     >>chng 97 june 9, get rid of go to, move lgEndFun to start
        do while( .not.lgEndFun() )
*7      continue
*     >>chng 97 june 9, zone increment at start not bottom
          nzone = nzone + 1
*         set variable dealing with new radius
          call zonsrt('incr')
*         do pressure-temperature-ionization balance
          call PIonte
*         evaluate total opacity, it was also done in ionize, called by PIonte
*     >>chng 97 may 6, ok checks that opacity scale is ok, not underflow to 0
          call AddOpac( lgOK )
          if( .not. lgOK ) then
            call prstep
            goto1
          endif
*         use changes in opacity, temperature, ionization, to fix new dr
          call NextDR
*         find diffuse emission from this zone
          call diffem
*         do work associated with incrementing this radius
          call radinc
*         diffuse fields of heavy elements, outward beams
          call metdif
*         fill in emission line array
          call lines
*         increment optical depths
          call TauInc
*         possibly punch out some results from this zone
          call DoPunch( 'MIDL' )
*         call print-step, update dr, and check on end conditions
*     >>chng 97 june 9, got rid of go to
*         if( lgEndFun() ) go to1
*         nzone = nzone + 1
*         do some things to finish out this zone
          call zondun
*       go to7
        end do
*
*       model complete
 1      continue
*       print out some comments, generate w, c that DoPunch may need
        call comment
*       punch stuff only needed on last shot
        call DoPunch( 'LAST' )
        call plot('SECND')
*       print out the results
        call final
        if( iter .gt. itermx ) return
*       update limiting optical depth variables
        call update
        iter = iter + 1
*       reinitialize some variables which may have changed
        nzone = 0
        call reset
        call zonsrt('init')
        call tfirst( lgOK )
*       punt if gas totally cold and molecular
        if( .not.lgOK ) return
      end do
      end
