*****************************************************************
      subroutine ConcatRauch
      implicit none
*K Volk's routine to compact the 57 Rauch atmospheres into a large ascii file.
* As the wavelengths are always the same only the fluxes
* will be written to the output file.
*
* Before running this program issue the following command where the Rauch
* model atmosphere files are kept (050000_50.wf and so on)
*
*   ls *.wf > rauchmods.list
*
* and check to see that there are 66 lines in the file.  The file name 
* "1000000_90_solar.wf" then has to be moved to the end of the file for 
* the models to be written to the ascii output file in the proper order.
*
      include "nopsv.par"
      include "opsv.com"
      include "IOqq.com"
*
*     local variables
      real wl
      integer ierr , i , j, k
      integer nfile
      parameter (nfile=66)
      character*10 chSuff
      character*20 chFName
      integer NameLength
      character*10 chFile(nfile)
      data chFile/
     1 '050000_50', '050000_60', '050000_70', '050000_80', '060000_50', 
     2 '060000_60', '060000_70', '060000_80', '070000_50', '070000_60', 
     3 '070000_70', '070000_80', '080000_50', '080000_60', '080000_70', 
     4 '080000_80', '090000_50', '090000_60', '090000_70', '090000_80', 
     5 '100000_50', '100000_60', '100000_70', '100000_80', '110000_60', 
     6 '110000_70', '110000_80', '120000_60', '120000_70', '120000_80', 
     7 '130000_60', '130000_70', '130000_80', '140000_60', '140000_70', 
     8 '140000_80', '150000_60', '150000_70', '150000_80', '160000_60', 
     9 '160000_70', '160000_80', '170000_60', '170000_70', '170000_80', 
     A '180000_60', '180000_70', '180000_80', '190000_60', '190000_70', 
     B '190000_80', '200000_70', '200000_80', '200000_90', '300000_70', 
     C '300000_80', '300000_90', '400000_80', '400000_90', '500000_80', 
     D '500000_90', '600000_90', '700000_90', '800000_90', '900000_90', 
     E '1000000_90'/
*
      write(qq,'(''ConcatRauch on the job.  This will take a while.'')')
*

      do k=1,2
      if (k.eq.1) then
          chFName='rauch_solar.ascii'
          chSuff='_solar.wf'
	    NameLength = 9
          write(qq,'(''Doing solar abundance set....'')')
      else
          chFName='rauch_halo.ascii'
          chSuff='_halo.wf'
	    NameLength = 8
          write(qq,'(''Doing halo abundance set....'')')
      endif
      open(unit=02,file=chFName, status='new',iostat=ierr)
      if( ierr.ne.0 ) then
        write(qq,'('' ConcatRauch could not open stars '',
     1  ''file '',a20)') chFName
        write(qq,'('' Make sure there is not already a file with '',
     1  ''this name.'')')
        stop
      endif
*
      do i=1,nfile
        write(qq,'('' star'',i3,1x,a12)') i, chFile(i)
*       get file name from list of star files
*       read(01,'(a12)',iostat=ierr) chFName
*       if( ierr.ne.0 ) then
*         write(qq,'('' ConcatRauch could not read stellar '',
*    1    ''atmosphile names '',i4)') i
*         stop
*       endif
*       open(unit=07,file=chFName,status='old',iostat=ierr)
*       open(unit=77,file=chFName,status='old',iostat=ierr)
        if (i.lt.nfile) then
*           chFName=chFile(i)(1:9)//suff
            chFName(1:9) = chFile(i)(1:9)
	      chFName(10:9+NameLength) = chSuff
	      chFName(10+NameLength:10+NameLength) = char(0)
        else
*            chFName=chFile(i)//suff
            chFName(1:10) = chFile(i)(1:10)
	      chFName(11:10+NameLength) = chSuff
	      chFName(11+NameLength:11+NameLength) = char(0)
        end if
        open(unit=77,file=chFName,status='old',iostat=ierr)
        if( ierr.ne.0 ) then
          write(qq,'('' ConcatRauch could not open stellar '',
     1    ''atmosphere file '',i4,'' name='',a20)') i,chFName
          stop
        endif
*
        do j=1,33
*         throw away the header information
          read(77,'(a1)',iostat=ierr) chFName(1:1)
          if( ierr.ne.0 ) then
            write(qq,'('' ConcatRauch error in header '',
     1      ''atmosphere file '',2i4)') i,j
            stop
          endif
        end do
*
        do j=1,19951
          read(77,'(f6.1,e10.3)',iostat=ierr) wl,OpacStack(j)
          if( ierr.ne.0 ) then
            write(qq,'('' ConcatRauch error in getting '',
     1      ''fluxes, file, nflux '',2i4,'' name='',a12)') i,j,chFile(i)
            stop
          endif
        end do
*
        close(77)
*
        write(02,'(1p9e9.3)') (OpacStack(j),j=1,19951)
      end do
*
      close(02)
      enddo
*
      stop
      end
