
******************************************************************************
      real function da( z )
      implicit none
*interpolate on three body recombination by Steve Cota
      real z
* 
* WRITTEN BY S. A. COTA, 2/87
*
      integer maxz
      parameter ( maxz = 28 )
*
* MAXZ IS THE MAXIMUM EFFECTIVE NUCLEAR CHARGE ( = IONIC CHARGE + 1 )
* WHICH THE DIMENSION STATEMENTS ACCOMODATE.  
*
* IT IS USED ONLY FOR THE ARRAY ZLOG7 ( = 7 * LOG ( Z ) ) 
* AND THE ARRAY ZLOG2 ( = 2 * LOG ( Z ) ) .   THESE ARRAYS
* CONTAIN EASILY CALCULATED VALUES, WHICH HAVE BEEN STORED
* TO SAVE TIME IN EXECUTION.
*
* IF MAXZ IS EXCEEDED, THIS PROGRAM SIMPLY CALCULATES THE
* LOGS INSTEAD OF LOOKING THEM UP.
*   
*
      include "logte.com"
      include "dalerr.com"
*
      include "parms.com"
      include "dax.com"
      include "xcx.com"
      include "xnx.com"
      include "IOqq.com"
*
*     local variables
      real xmap , xinvrs,alognc,alogn,alogt,zlog,expp
      integer nt0,nt1,jfail,nt,nz
      real c, d, u, v, a, b, x, y, xnc
*
      real xx(3), yya(3), yyb(3), yyx(3), yyy(3)
*     logical lgInterp
*
*     lgInterp = .true.
*
*begin sanity check
      if( zlog7(2).le.0. ) then
        write(qq,'('' Insane value in zlog7 array.'')')
        write(qq,'('' Was block data dalpha linked in?'')')
        stop
      endif
*end sanity check
*
      nz = z + .1
      if ( nz .gt. maxz ) then
        zlog = alog10 ( z )
        alogt = alogte - 2. * zlog 
        alogn = alogne - 7. * zlog
      else
        alogt = alogte - zlog2 (nz)
        alogn = alogne - zlog7 (nz)
      endif
*
* CHECK IF PARAMETERS ARE WITHIN BOUNDS.  IF NOT, INCREMENT
*       APPROPRIATE ERROR COUNTER AND SET TO BOUNDARY IF 
*       NECESSARY:
*   
* DEFINITION OF ERROR COUNTERS:
*
*     ILT    : LOW T         
*     ILTLN  : LOW T , LOW  N
*     ILTHN  : LOW T , HIGH N
*     IHTHN  : HIGH T , HIGH N 
*
      if  ( alogt .lt. 0. ) then 
        ilt = ilt + 1
        alogt = 0.
      endif
*
      if  ( alogt .le. 2.1760913 ) then
        if  ( alogn .lt. ( 3.5 * alogt - 8. ) ) then
          iltln = iltln + 1
        else if ( alogn .gt. ( 3.5 * alogt - 2. ) ) then
          ilthn = ilthn + 1
          alogn = 3.5 * alogt - 2.
        endif
*
      else if ( alogt .le. 2.4771213 ) then
        if ( alogn .gt. 9. ) then
          ilthn = ilthn + 1 
          alogn = 9.
        endif
*
      else if ( alogt .le. 5.1139434 ) then
        if ( alogn .gt. 13. ) then
          ihthn = ihthn + 1
          alogn = 13.
        endif
*
      else
        da  = 0.
        return
      endif
* 
* LOCATE POSITION IN ARRAYS
*
      if ( alogt .le. 2. ) then
        nt  = 9.9657843 * alogt + 1.
      else 
        nt = 19.931568 * alogt - 19.
      endif
      nt = max( 1 , min( 83 , nt ) )
*
* CENTER UP SINCE ARRAY VALUES ARE ROUNDED
*
      if ( abs ( alogt - tz ( nt ) ) .ge. 
     *     abs ( alogt - tz ( min(83,nt+1) ) ) ) then
        nt = min( 83 , nt + 1 )
      else if ( abs ( alogt - tz ( nt  ) ) .gt.
     *          abs ( alogt - tz ( max(1,nt - 1) ) ) ) then
        nt  = max( 1 , nt - 1 )
      endif
*
* CHECK IF INTERPOLATION IS NEEDED AND PROCEED IF NOT.
*
      if ( abs ( alogt - tz ( nt ) ) .lt. 0.00001 ) then
        if ( z .ne. 1.0 ) then
          c = a1 ( nt )
          d = b1 ( nt )
          u = x1 ( nt )
          v = 8.90
        else
          nt = min( 83 , max( 21 , nt ) )
          c = a2 ( nt )
          d = b2 ( nt )
          u = x2 ( nt )
          v = 9.40
        endif
*
        xnc    = xinvrs ( alogn , c , d , u , v , jfail )
        if( xnc.le.0. .or. jfail.ne.0 ) then
           ifail = 1
           jfail = 1
           da = 0.
           return
        endif
        alognc = alog10 ( xnc )
*
        a      = a0 ( nt )
        b      = b0 ( nt )
        x      = -2.45    
        y      = x0 ( nt )
        nt0    = nt - 1
*
*   IF INTERPOLATION WAS REQUIRED, 
*   CHECK THAT NT IS NOT ON THE EDGE OF A DISCONTINUITY,
*   EITHER AT END OF ARRAYS OR WITHIN THEM,
*   WHERE VALUES CHANGE ABRUPTLY.
*
      else 
        if ( ( nt .le. 21 ) .and. ( z .eq. 1.0 ) ) then
          nt = 22
        else if ( nt .le. 1 ) then
          nt = 2 
        else if ( nt .ge. 83 ) then
          nt = 82
        else if ( nt .eq. 24 ) then
          if ( alogt .le. 2.1760913 ) then
            nt = 23
          else                       
            nt = 25 
          endif
        else if ( nt .eq. 30 ) then
          if ( alogt .le. 2.4771213 ) then
            nt = 29
          else                       
            nt = 31
          endif
        endif
*
        nt0 = nt - 1
        nt1 = nt + 1
        xx ( 1 ) = tz ( nt0 )
        xx ( 2 ) = tz  ( nt )
        xx ( 3 ) = tz ( nt1 )
*
        if ( z .ne. 1.0 ) then
          if ( nt0 .eq. 24 ) then
            yya ( 1 ) = 17.2880135
            yyb ( 1 ) = 6.93410742e+03
            yyx ( 1 ) = -3.75
          else if ( nt0 .eq. 30 ) then
            yya ( 1 ) = 17.4317989
            yyb ( 1 ) = 1.36653821e+03
            yyx ( 1 ) = -3.40
          else
            yya ( 1 ) = a1( nt0 )
            yyb ( 1 ) = b1( nt0 )
            yyx ( 1 ) = x1( nt0 )
          endif
*
          yya ( 2 ) = a1( nt  )
          yya ( 3 ) = a1( nt1 )
          c       =  xmap ( xx , yya , alogt )
          yyb ( 2 ) = b1( nt  )
          yyb ( 3 ) = b1( nt1 )
          d       = xmap ( xx , yyb , alogt )
          yyx ( 2 ) = x1( nt  )
          yyx ( 3 ) = x1( nt1 )
          u        = xmap ( xx , yyx , alogt )
          v        = 8.90
*
        else
          if ( nt0 .eq. 24 ) then
            yya ( 1 ) = 20.1895161
            yyb ( 1 ) = 2.25774918e+01
            yyx ( 1 ) = -1.66
          else if ( nt0 .eq. 30 ) then
            yya ( 1 ) = 19.8647804
            yyb ( 1 ) = 6.70408707e+02
            yyx ( 1 ) = -2.12
          else
            yya ( 1 ) = a2( nt0 )
            yyb ( 1 ) = b2( nt0 )
            yyx ( 1 ) = x2( nt0 )
          endif
*
          yya ( 2 ) = a2( nt  )
          yya ( 3 ) = a2( nt1 )
          c       =  xmap ( xx , yya , alogt )
          yyb ( 2 ) = b2( nt  )
          yyb ( 3 ) = b2( nt1 )
          d       = xmap ( xx , yyb , alogt )
          yyx ( 2 ) = x2( nt  )
          yyx ( 3 ) = x2( nt1 )
          u        = xmap ( xx , yyx , alogt )
          v        = 9.40
        endif
*
        xnc    = xinvrs ( alogn , c , d , u , v , jfail )
        if( xnc.le.0. .or. jfail.ne.0 ) then
           ifail = 1
           jfail = 1
           da = 0.
           return
        endif
        alognc = alog10 ( xnc )
*
        if ( nt0 .eq. 24 ) then
          yya ( 1 ) = -8.04963875
          yyb ( 1 ) = 1.07205127e+03
          yyy ( 1 ) = 2.05
        else if ( nt0 .eq. 30 ) then
          yya ( 1 ) = -8.54721069
          yyb ( 1 ) = 4.70450195e+02
          yyy ( 1 ) = 2.05      
        else
          yya ( 1 ) = a0 ( nt0 )
          yyb ( 1 ) = b0 ( nt0 )
          yyy ( 1 ) = x0 ( nt0 )
        endif
*
        yya ( 2 ) = a0 ( nt  )
        yya ( 3 ) = a0 ( nt1 )
        a       = xmap ( xx , yya , alogt )
        yyb ( 2 ) = b0 ( nt  )
        yyb ( 3 ) = b0 ( nt1 )
        b       = xmap ( xx , yyb , alogt )
        x         = -2.45
        yyy ( 2 ) = x0 ( nt  )
        yyy ( 3 ) = x0 ( nt1 )
        y         = xmap ( xx , yyy, alogt )
      endif
*
      expp = ( a - y * alognc + b * xnc ** x )
      IF( expp.lt.37 ) then
         da = z * 10. ** expp
      else
         da = 0.
      endif
      ifail = ifail + jfail
*
      end 
