      subroutine GetWerner
      implicit none
*rebin Werner stellar atmospheres to match cloudy energy grid
      include "ncell.par"
      include "rfield.com"
      include "widflx.com"
      include "corind.com"
      include "StarSize.com"
      include "StarBad.com"
      include "IOqq.com"
*
*     local variables
      integer j , n1 , i , n2 , imod , ierr
      integer iout(ncell)
*     real freq(ncell) , flux2(ncell)
*     freq changed to anu2, flux2 changed to ContBoltz
*
      write(qq,'('' GetWerner on the job.'')')
c This is a program to re-bin the Werner stellar model spectra to match the 
c CLOUDY grid.  For short wavelengths I will use a power law extrapolation
c of the model values (which should be falling rapidly) if needed.  At long
c wavelengths I will assume Rayleigh-Jeans from the last stellar model point
c to extrapolate to 1 cm wavelength.
c
c This version uses power-law interpolation between the points of the stellar
c model.
c
c If ncell is changed the format statement below must also be changed.
c If the size of the CLOUDY frequency grid becomes larger than ncell the 
c arrays below would have to be increased in size.
c
c
c This file holds the energy bin values (center energy and bin width, both in 
c Rydberg units) as written out by CLOUDY.  The file has two header lines.
c
c For putting this in CLOUDY the arrrays "anu" and "widflx" would have to be 
c passed into the routine.
c
*      read in the cloudy energy grid, converting to integers
       n1 = 1
       do while( anu(n1).lt.182. ) 
         iout(n1) = int(abs(log10(anu(n1))-5.)*1.e+06)
         n1 = n1 + 1
       end do
       n1 = n1 - 1
c
       write(qq,'('' A total of '',i4,'' Cloudy cells needed.'')') n1
       if( n1.eq.nWerner ) then
         write(qq,'('' The current value of nWerner is ok.'')')
       else
         if( .not.lgStarBad ) then
*          no errors yet, so open errors file
           open(unit=66,file='problems.out',status='unknown')
         endif
         lgStarBad = .true.
         write(qq,'('' WARNING!!!!!'')')
         write(qq,'('' WARNING!!!!!'')')
         write(qq,'('' nWerner must be changed to'',i6,
     1   '' in block data scalar.  Its current value is'',i6)')
     2   n1,nWerner
         write(66,'('' nWerner must be changed to'',i6,
     1   '' in block data scalar.  Its current value is'',i6)')
     2   n1,nWerner
         write(qq,'('' I will take care of this for now.'')')
         nWerner = n1
       endif
c
c **** Note that n1 has to be set for this program to be changed to a subroutine.
c It is the number of values in the CLOUDY frequency array. *********
c
      open(unit=01,file='werner.ascii',status='old',iostat=ierr)
      if( ierr.ne.0 ) then
        write(qq,'('' GetWerner fails opening werner.ascii'')')
        write(qq,'('' Where is this file?'')')
        stop
      endif
c This "werner.ascii" file is a straight ascii dump of the Klaus Werner 
c stellar model files which he gave to me in 1992.  The first set of values 
c is the 80000 K log(g)=5.0 model fluxes, followed by the wavelength grid, 
c followed by the other models in order of increasing log(g) and temperature.
c
      open(unit=11,file='werner.mod',iostat=ierr,status='unknown',
     c     access='direct',form='formatted',recl=7*ncell)
      if( ierr.ne.0 ) then
        write(qq,'('' GetWerner fails creating werner.mod'')')
        write(qq,'('' This is impossible??'')')
        stop
      else
        write(qq,'('' GetWerner creating werner.mod OK'')')
      endif
      write(11,'(4000i7)',rec=1) (iout(j),j=1,n1)
c
      do imod=2,21
      if (imod.eq.2) then
*       only for first one, get energy grid
*     >>chng 97 jan 5, get rid of statement
        read(01,'(5e15.7)',iostat=ierr) (anu2(i),i=1,514)
*55   format(5e15.7)
        if( ierr.ne.0 ) then
          write(qq,'('' GetWerner fails reading energy grid1.'')')
          stop
        endif
        do i=1,513
          anu2(i) = 299792458.*10973731.534*anu2(i+1)
        end do
c this converts the Rydberg values to Hz since I want to use the 
c same interpolation subroutine for the Werner and the Kurucz models,
c and the Kurucz models are expressed as a function of frequency.
c
c The Klaus Werner model wavelength grid was converted to Rydberg units 
c when I originally created the direct access file, but here they are 
c converted back to Hz.
      end if
*     >>chng 97 jan 5, get rid of statement
      read(01,'(5e15.7)',iostat=ierr) (flux(i),i=1,514)
*55   format(5e15.7)
      if( ierr.ne.0 ) then
        write(qq,'('' GetWerner fails getting wavelenghts.'')')
        stop
      endif
c
      do i=1,513
        flux(i)=10.**flux(i+1)
        if(i.gt.1) then
          if( anu2(i).eq.anu2(i-1) ) then
* change 96 apr 12, gjf, to avoid double precision
            anu2(i-1)=anu2(i-1)*0.999
            anu2(i)=anu2(i)*1.001
          end if
c This is due to there being fluxes above and below certain wavelengths where 
c the opacity changes (i.e. the Lyman and Balmer limits for example) which are 
c assigned the same wavelength in the Klaus Werner files.
        end if
      end do
c
c The first value in the spectrum read in from the "werner.ascii" file is not 
c one of the original Klaus Werner model values but is an extrapolation to 
c long wavelength...so I remove it in the loop.
c
      n2=513
      flux(514)=0.0d+00
      anu2(514)=0.0d+00
      call RebinWer(n1,n2)
c
      do j=1,n1
        if (ContBoltz(j).gt.1e-30 ) then
          iout(j) = int(abs(log10(ContBoltz(j))-3.)*100000.)
        else
          iout(j) = 9999999
        endif
      end do
c
      write(11,'(4000i7)',rec=imod) (iout(j),j=1,n1)
*
      write(qq,'('' GetWerner wrote stellar atmosphere number'',i3)')
     1 imod
      end do
*
      close(01)
      close(unit=11)
      write(qq,'('' GetWerner completed ok, werner.ascii '',
     1''can be deleted.'')')
*
      end
