******************************************************************************
      real function SumCTHeat( )
      implicit none
*sum net heating due to charge transfer
      include "limelm.par"
      include "CharExc.com"
      include "h.com"
      include "IonFracs.com"
      include "heat.com"
*
      real CTIon
      common/CTIon/ CTIon(8,4,limelm)
      real CTRecomb
*     second dimension is ionization stage,
*     1=+1 for parent, etc
*     third dimension is atomic weight of atom
      common/CTRecomb/ CTRecomb(7,4,limelm)
*
*     begin local variables
      integer nelem , ion
*
      SumCTHeat = 0.
      do nelem=1,limelm
*       first group have exact numbers
        do ion=1,4
          SumCTHeat = SumCTHeat + HCharExcIon(ion,nelem)*hii*
     1    xIonFracs(nelem,ion) * CTIon(8,ion,nelem) +
     1    HCharExcRec(ion,nelem)*hi*xIonFracs(nelem,ion+1) * 
     1    CTRecomb(7,ion,nelem)
        end do
*       >>chng 98 sep 23, lower limit had been 4, double counted with above
*       following do not have exact energies, so use 2.86*(Z-1)
        do ion=5,limelm
          SumCTHeat = SumCTHeat +
     1    HCharExcRec(ion,nelem)*hi*xIonFracs(nelem,ion+1) *2.86*ion
        end do
      end do
*
*     convert from eV to ergs, HCharHeatOn usually 1, set to 0 with no CTHeat
      SumCTHeat = SumCTHeat * 1.602e-12 * HCharHeatOn
      if( htot.gt.1e-35 ) then
*       write(66,*) SumCTHeat/ htot
*       remember largest fractions of heating and cooling for comment
        HCharHeatMax = max( HCharHeatMax , SumCTHeat / htot )
        HCharCoolMax = max( HCharCoolMax , -SumCTHeat/ htot )
      endif
*
      end
******************************************************************************
      real function HCTIon(ion,nelem)
      implicit none
*H charge transfer ionization, using Jim Kingdon's ctdata.for
      integer ion , nelem
*     ion is stage of ionization, 1 for atom
*     nelem is atomic number of element, 2 up to 30
      include "limelm.par"
      include "phycon.com"
      include "IOqq.com"
      real CTIon
      common/CTIon/ CTIon(8,4,limelm)
*
*     local variables
      real tused 
      integer ipIon
*
      ipIon = ion
*
*being sanity check
      if( CTIon(1,1,3).le.0. ) then
        write(qq,'('' Non-positive coefficient for charge trnasfer.'')')
        write(qq,'('' Was block data ctdata linked in?'')')
        call insane
        stop
      endif
*end sanity check
*
*     return zero for highly ionized species
      if( ion.ge.4 ) then
        HCTIon = 0.
        return
      endif
*
*begin sanity checks
      if( ipIon.lt.1 .or. ipIon.gt.nelem ) then
        write(qq,'('' HTRecom called with insane ion stage'',2i4)')ion,
     1  nelem
        stop
      endif
      if( nelem.lt.2 .or. nelem.gt. limelm )  then
        write(qq,'('' HTRecom called with insane atomic number'',2i4)')
     1  ion, nelem
        stop
      endif
*end sanity checks
*
*     may be no entry, first coefficient is zero in this case
      if( CTIon(1,ipIon,nelem) .le.0. ) then
        HCTIon = 0.
        return
      endif
*
*     Make sure te is between temp. boundaries; set constant outside of range
      tused = max( te,CTIon(5,ipIon,nelem) )
      tused = min( tused , CTIon(6,ipIon,nelem) )
      tused = tused * 1e-4
*
*     the interpolation equation
      HCTIon = CTIon(1,ipIon,nelem)* 1e-9 * 
     1 (tused**CTIon(2,ipIon,nelem)) *
     2 (1. + 
     3 CTIon(3,ipIon,nelem) * exp(CTIon(4,ipIon,nelem)*tused) ) *
     4 exp(-CTIon(7,ipIon,nelem)/tused)
*
      end
******************************************************************************
      real function HCTRecom(ion,nelem)
      implicit none
*H charge transfer recombination using Jim Kingdon's block ctdata.for
*     ion is stage of ionization, 1 for rec to atom
*     nelem is atomic number of element, 2 up to limelm
      integer ion , nelem
      include "limelm.par"
      include "phycon.com"
      include "HCTMin.com"
      include "IOqq.com"
*
      real CTRecomb
*     second dimension is ionization stage,
*     1=+1 for parent, etc
*     third dimension is atomic weight of atom
      common/CTRecomb/ CTRecomb(7,4,limelm)
*
*     local variables
      real tused , sexp
      integer ipIon
*
*     subtract 1 since atom can't happen, is not in block data
      ipIon = ion
*
*begin sanity check
      if( CTRecomb(1,1,2).le.0. ) then
        write(qq,'('' Insane value in CTRecomb array.'')')
        write(qq,'('' Was block data ctdata lined in?'')')
        stop
      endif
*end sanity check
*
*     use Dalgarno estimate for highly ionized species, number reset with
*     set charge transfer command
      if( ipIon.gt.4 ) then
*       >>chng 96 nov 25, added this option, default is 1.92e-9
*       Dalgarno's charge transfer
        HCTRecom = HCTAlex * ipIon
        return
      endif
*
*begin sanity checks
      if( ipIon.lt.1 .or. ipIon.gt. nelem ) then
        write(qq,'('' HCTRecom called with insane ion stage'',2i4)')ion,
     1  nelem
        stop
      endif
      if( nelem.lt.2 .or. nelem.gt. limelm )  then
        write(qq,'('' HCTRecom called with insane atomic number'',2i4)')
     1  ion, nelem
        stop
      endif
*end sanity checks
      tused = max( te,CTRecomb(5,ipIon,nelem) )
      tused = min( tused , CTRecomb(6,ipIon,nelem) )
      tused = tused * 1e-4
      if( tused.eq.0. ) then
        HCTRecom = 0.
        return
      endif
*
*     the interpolation equation
      HCTRecom = CTRecomb(1,ipIon,nelem)* 1e-9 * 
     1 (tused**CTRecomb(2,ipIon,nelem)) *
     2 (1. + 
     3 CTRecomb(3,ipIon,nelem) * sexp(- CTRecomb(4,ipIon,nelem)*tused) )
*     in sexp negative sign not typo - there are negative signs already
*     in coefficient, and sexp has implicit negative sign
*
      end
********************************************************************************
      block data ctdata
      implicit none
*block data with Jim Kingdon's charge transfer data
*
      real CTIon
*     second dimension is ionization stage,
*     1=+0 for parent, etc
*     third dimension is atomic number of atom
      common/CTIon/ CTIon(8,4,30)
      real CTRecomb
*     second dimension is ionization stage,
*     1=+1 for parent, etc
*     third dimension is atomic number of atom
      common/CTRecomb/ CTRecomb(7,4,30)
*
*     local variables
      integer i
*
*     digital form of the fits to the charge transfer
*     ionization rate coefficients 
*
*     Note: First parameter is in units of 1e-9!
*     Note: Seventh parameter is in units of 1e4 K
      data (CTIon(i,1,3),i=1,8)/2.84e-3,1.99,375.54,-54.07,1e2,1e4,0.0,
     1 -10./
      data (CTIon(i,2,3),i=1,8)/8*0./
      data (CTIon(i,3,3),i=1,8)/8*0./
      data (CTIon(i,1,4),i=1,8)/8*0./
      data (CTIon(i,2,4),i=1,8)/8*0./
      data (CTIon(i,3,4),i=1,8)/8*0./
      data (CTIon(i,1,5),i=1,8)/8*0./
      data (CTIon(i,2,5),i=1,8)/8*0./
      data (CTIon(i,3,5),i=1,8)/8*0./
      data (CTIon(i,1,6),i=1,8)/1.07e-6,3.15,176.43,-4.29,1e3,1e5,0.0,
     1  2.34/
      data (CTIon(i,2,6),i=1,8)/8*0./
      data (CTIon(i,3,6),i=1,8)/8*0./
      data (CTIon(i,1,7),i=1,8)/4.55e-3,-0.29,-0.92,-8.38,1e2,5e4,1.086,
     1 -0.94/
      data (CTIon(i,2,7),i=1,8)/8*0./
      data (CTIon(i,3,7),i=1,8)/8*0./
      data (CTIon(i,1,8),i=1,8)/7.40e-2,0.47,24.37,-0.74,1e1,1e4,0.023,
     1 -0.02/
      data (CTIon(i,2,8),i=1,8)/8*0./
      data (CTIon(i,3,8),i=1,8)/8*0./
      data (CTIon(i,1,9),i=1,8)/8*0./
      data (CTIon(i,2,9),i=1,8)/8*0./
      data (CTIon(i,3,9),i=1,8)/8*0./
      data (CTIon(i,1,10),i=1,8)/8*0./
      data (CTIon(i,2,10),i=1,8)/8*0./
      data (CTIon(i,3,10),i=1,8)/8*0./
      data (CTIon(i,1,11),i=1,8)/3.34e-6,9.31,2632.31,-3.04,1e3,2e4,0.0,
     1 -1.74/
      data (CTIon(i,2,11),i=1,8)/8*0./
      data (CTIon(i,3,11),i=1,8)/8*0./
      data (CTIon(i,1,12),i=1,8)/9.76e-3,3.14,55.54,-1.12,5e3,3e4,0.0,
     1 1.52/
      data (CTIon(i,2,12),i=1,8)/7.60e-5,0.00,-1.97,-4.32,1e4,3e5,1.670,
     1 -1.44/
      data (CTIon(i,3,12),i=1,8)/8*0./
      data (CTIon(i,1,13),i=1,8)/8*0./
      data (CTIon(i,2,13),i=1,8)/8*0./
      data (CTIon(i,3,13),i=1,8)/8*0./
      data (CTIon(i,1,14),i=1,8)/0.92,1.15,0.80,-0.24,1e3,2e5,0.0,0.12/
      data (CTIon(i,2,14),i=1,8)/2.26,7.36e-2,-0.43,-0.11,2e3,1e5,
     1 3.031, -2.72/
      data (CTIon(i,3,14),i=1,8)/8*0./
      data (CTIon(i,1,15),i=1,8)/8*0./
      data (CTIon(i,2,15),i=1,8)/8*0./
      data (CTIon(i,3,15),i=1,8)/8*0./
      data (CTIon(i,1,16),i=1,8)/1.00e-5,0.00,0.00,0.00,1e3,1e4,0.0,
     1 -3.24/
      data (CTIon(i,2,16),i=1,8)/8*0./
      data (CTIon(i,3,16),i=1,8)/8*0./
      data (CTIon(i,1,17),i=1,8)/8*0./
      data (CTIon(i,2,17),i=1,8)/8*0./
      data (CTIon(i,3,17),i=1,8)/8*0./
      data (CTIon(i,1,18),i=1,8)/8*0./
      data (CTIon(i,2,18),i=1,8)/8*0./
      data (CTIon(i,3,18),i=1,8)/8*0./
      data (CTIon(i,1,19),i=1,8)/8*0./
      data (CTIon(i,2,19),i=1,8)/8*0./
      data (CTIon(i,3,19),i=1,8)/8*0./
      data (CTIon(i,1,20),i=1,8)/8*0./
      data (CTIon(i,2,20),i=1,8)/8*0./
      data (CTIon(i,3,20),i=1,8)/8*0./
      data (CTIon(i,1,21),i=1,8)/8*0./
      data (CTIon(i,2,21),i=1,8)/8*0./
      data (CTIon(i,3,21),i=1,8)/8*0./
      data (CTIon(i,1,22),i=1,8)/8*0./
      data (CTIon(i,2,22),i=1,8)/8*0./
      data (CTIon(i,3,22),i=1,8)/8*0./
      data (CTIon(i,1,23),i=1,8)/8*0./
      data (CTIon(i,2,23),i=1,8)/8*0./
      data (CTIon(i,3,23),i=1,8)/8*0./
      data (CTIon(i,1,24),i=1,8)/8*0./
      data (CTIon(i,2,24),i=1,8)/4.39,0.61,-0.89,-3.56,1e3,3e4,3.349,
     1 -2.89/
      data (CTIon(i,3,24),i=1,8)/8*0./
      data (CTIon(i,1,25),i=1,8)/8*0./
      data (CTIon(i,2,25),i=1,8)/2.83e-1,6.80e-3,6.44e-2,-9.70,1e3,3e4,
     1 2.368,-2.04/
      data (CTIon(i,3,25),i=1,8)/8*0./
      data (CTIon(i,1,26),i=1,8)/8*0./
      data (CTIon(i,2,26),i=1,8)/2.10,7.72e-2,-0.41,-7.31,1e4,1e5,3.005,
     1 -2.56/
      data (CTIon(i,3,26),i=1,8)/8*0./
      data (CTIon(i,1,27),i=1,8)/8*0./
      data (CTIon(i,2,27),i=1,8)/1.20e-2,3.49,24.41,-1.26,1e3,3e4,4.044,
     1 -3.49/
      data (CTIon(i,3,27),i=1,8)/8*0./
      data (CTIon(i,1,28),i=1,8)/8*0./
      data (CTIon(i,2,28),i=1,8)/8*0./
      data (CTIon(i,3,28),i=1,8)/8*0./
      data (CTIon(i,1,29),i=1,8)/8*0./
      data (CTIon(i,2,29),i=1,8)/8*0./
      data (CTIon(i,3,29),i=1,8)/8*0./
      data (CTIon(i,1,30),i=1,8)/8*0./
      data (CTIon(i,2,30),i=1,8)/8*0./
      data (CTIon(i,3,30),i=1,8)/8*0./
*
*     digital form of the fits to the charge transfer
*     recombination rate coefficients (total)
*
*     Note: First parameter is in units of 1e-9!
*     recombination
      data (CTRecomb(i,1,2),i=1,7)/7.47e-6,2.06,9.93,-3.89,6e3,1e5,
     1 10.99/
      data (CTRecomb(i,2,2),i=1,7)/1.00e-5,0.,0.,0.,1e3,1e7,-40.81/
      data (CTRecomb(i,1,3),i=1,7)/7*0./
      data (CTRecomb(i,2,3),i=1,7)/1.26,0.96,3.02,-0.65,1e3,3e4,3.02/
      data (CTRecomb(i,3,3),i=1,7)/1.00e-5,0.,0.,0.,2e3,5e4,-108.83/
      data (CTRecomb(i,1,4),i=1,7)/7*0./
      data (CTRecomb(i,2,4),i=1,7)/1.00e-5,0.,0.,0.,2e3,5e4,-4.61/
      data (CTRecomb(i,3,4),i=1,7)/1.00e-5,0.,0.,0.,2e3,5e4,-140.26/
      data (CTRecomb(i,4,4),i=1,7)/5.17,0.82,-0.69,-1.12,2e3,5e4,10.59/
      data (CTRecomb(i,1,5),i=1,7)/7*0./
      data (CTRecomb(i,2,5),i=1,7)/2.00e-2,0.,0.,0.,1e3,1e9,2.46/
      data (CTRecomb(i,3,5),i=1,7)/1.00e-5,0.,0.,0.,2e3,5e4,-24.33/
      data (CTRecomb(i,4,5),i=1,7)/2.74,0.93,-0.61,-1.13,2e3,5e4,11./
      data (CTRecomb(i,1,6),i=1,7)/4.88e-7,3.25,-1.12,-0.21,5.5e3,
     1 1e5, -2.34/
      data (CTRecomb(i,2,6),i=1,7)/1.67e-4,2.79,304.72,-4.07,5e3,5e4,
     1 4.01/
      data (CTRecomb(i,3,6),i=1,7)/3.25,0.21,0.19,-3.29,1e3,1e5,5.73/
      data (CTRecomb(i,4,6),i=1,7)/332.46,-0.11,-9.95e-1,-1.58e-3,1e1,
     1 1e5,11.30/
      data (CTRecomb(i,1,7),i=1,7)/1.01e-3,-0.29,-0.92,-8.38,1e2,5e4,
     1 0.94/
      data (CTRecomb(i,2,7),i=1,7)/3.05e-1,0.60,2.65,-0.93,1e3,1e5,
     1 4.56/
      data (CTRecomb(i,3,7),i=1,7)/4.54,0.57,-0.65,-0.89,1e1,1e5,6.40/
      data (CTRecomb(i,4,7),i=1,7)/2.95,0.55,-0.39,-1.07,1e3,1e6,11./
      data (CTRecomb(i,1,8),i=1,7)/1.04,3.15e-2,-0.61,-9.73,1e1,1e4,
     1 0.02/
      data (CTRecomb(i,2,8),i=1,7)/1.04,0.27,2.02,-5.92,1e2,1e5,6.65/
      data (CTRecomb(i,3,8),i=1,7)/3.98,0.26,0.56,-2.62,1e3,5e4,5./
      data (CTRecomb(i,4,8),i=1,7)/2.52e-1,0.63,2.08,-4.16,1e3,3e4,8.47/
      data (CTRecomb(i,1,9),i=1,7)/7*0./
      data (CTRecomb(i,2,9),i=1,7)/1.00e-5,0.,0.,0.,2e3,5e4,-21.37/
      data (CTRecomb(i,3,9),i=1,7)/9.86,0.29,-0.21,-1.15,2e3,5e4,5.6/
      data (CTRecomb(i,4,9),i=1,7)/7.15e-1,1.21,-0.70,-0.85,2e3,5e4,
     1 11.8/
      data (CTRecomb(i,1,10),i=1,7)/7*0./
      data (CTRecomb(i,2,10),i=1,7)/1.00e-5,0.,0.,0.,5e3,5e4,-27.36/
      data (CTRecomb(i,3,10),i=1,7)/14.73,4.52e-2,-0.84,-0.31,5e3,5e4,
     1 5.82/
      data (CTRecomb(i,4,10),i=1,7)/6.47,0.54,3.59,-5.22,1e3,3e4,8.60/
      data (CTRecomb(i,1,11),i=1,7)/7*0./
      data (CTRecomb(i,2,11),i=1,7)/1.00e-5,0.,0.,0.,2e3,5e4,-33.68/
      data (CTRecomb(i,3,11),i=1,7)/1.33,1.15,1.20,-0.32,2e3,5e4,6.25/
      data (CTRecomb(i,4,11),i=1,7)/1.01e-1,1.34,10.05,-6.41,2e3,5e4,
     1 11./
      data (CTRecomb(i,1,12),i=1,7)/7*0./
      data (CTRecomb(i,2,12),i=1,7)/8.58e-5,2.49e-3,2.93e-2,-4.33,1e3,
     1 3e4,1.44/
      data (CTRecomb(i,3,12),i=1,7)/6.49,0.53,2.82,-7.63,1e3,3e4,5.73/
      data (CTRecomb(i,4,12),i=1,7)/6.36,0.55,3.86,-5.19,1e3,3e4,8.60/
      data (CTRecomb(i,1,13),i=1,7)/7*0./
      data (CTRecomb(i,2,13),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-5.23/
      data (CTRecomb(i,3,13),i=1,7)/7.11e-5,4.12,1.72e4,-22.24,1e3,3e4,
     1 8.17/
      data (CTRecomb(i,4,13),i=1,7)/7.52e-1,0.77,6.24,-5.67,1e3,3e4,8./
      data (CTRecomb(i,1,14),i=1,7)/7*0./
      data (CTRecomb(i,2,14),i=1,7)/6.77,7.36e-2,-0.43,-0.11,5e2,1e5,
     1 2.72/
      data (CTRecomb(i,3,14),i=1,7)/4.90e-1,-8.74e-2,-0.36,-0.79,1e3,
     1 3e4,4.23/
      data (CTRecomb(i,4,14),i=1,7)/7.58,0.37,1.06,-4.09,1e3,5e4,7.49/
      data (CTRecomb(i,1,15),i=1,7)/7*0./
      data (CTRecomb(i,2,15),i=1,7)/1.74e-4,3.84,36.06,-0.97,1e3,3e4,
     1 3.45/
      data (CTRecomb(i,3,15),i=1,7)/9.46e-2,-5.58e-2,0.77,-6.43,1e3,3e4,
     1 7.29/
      data (CTRecomb(i,4,15),i=1,7)/5.37,0.47,2.21,-8.52,1e3,3e4,9.71/
      data (CTRecomb(i,1,16),i=1,7)/3.82e-7,11.10,2.57e4,-8.22,1e3,1e4,
     1 -3.24/
      data (CTRecomb(i,2,16),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-9.73/
      data (CTRecomb(i,3,16),i=1,7)/2.29,4.02e-2,1.59,-6.06,1e3,3e4,
     1 5.73/
      data (CTRecomb(i,4,16),i=1,7)/6.44,0.13,2.69,-5.69,1e3,3e4,8.60/
      data (CTRecomb(i,1,17),i=1,7)/7*0./
      data (CTRecomb(i,2,17),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-10.21/
      data (CTRecomb(i,3,17),i=1,7)/1.88,0.32,1.77,-5.70,1e3,3e4,8./
      data (CTRecomb(i,4,17),i=1,7)/7.27,0.29,1.04,-10.14,1e3,3e4,9./
      data (CTRecomb(i,1,18),i=1,7)/7*0./
      data (CTRecomb(i,2,18),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-14.03/
      data (CTRecomb(i,3,18),i=1,7)/4.57,0.27,-0.18,-1.57,1e3,3e4,5.73/
      data (CTRecomb(i,4,18),i=1,7)/6.37,0.85,10.21,-6.22,1e3,3e4,8.60/
      data (CTRecomb(i,1,19),i=1,7)/7*0./
      data (CTRecomb(i,2,19),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-18.02/
      data (CTRecomb(i,3,19),i=1,7)/4.76,0.44,-0.56,-0.88,1e3,3e4,6./
      data (CTRecomb(i,4,19),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-47.3/
      data (CTRecomb(i,1,20),i=1,7)/7*0./
      data (CTRecomb(i,2,20),i=1,7)/0.,0.,0.,0.,1e1,1e9,0./
      data (CTRecomb(i,3,20),i=1,7)/3.17e-2,2.12,12.06,-0.40,1e3,3e4,
     1 6.6/
      data (CTRecomb(i,4,20),i=1,7)/2.68,0.69,-0.68,-4.47,1e3,3e4,
     1 9.9/
      data (CTRecomb(i,1,21),i=1,7)/7*0./
      data (CTRecomb(i,2,21),i=1,7)/0.,0.,0.,0.,1e1,1e9,0./
      data (CTRecomb(i,3,21),i=1,7)/7.22e-3,2.34,411.50,-13.24,1e3,3e4,
     1 3.5/
      data (CTRecomb(i,4,21),i=1,7)/1.20e-1,1.48,4.00,-9.33,1e3,3e4,
     1 10.61/
      data (CTRecomb(i,1,22),i=1,7)/7*0./
      data (CTRecomb(i,2,22),i=1,7)/0.,0.,0.,0.,1e1,1e9,0./
      data (CTRecomb(i,3,22),i=1,7)/6.34e-1,6.87e-3,0.18,-8.04,1e3,3e4,
     1 4.3/
      data (CTRecomb(i,4,22),i=1,7)/4.37e-3,1.25,40.02,-8.05,1e3,3e4,
     1 5.3/
      data (CTRecomb(i,1,23),i=1,7)/7*0./
      data (CTRecomb(i,2,23),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-1.05/
      data (CTRecomb(i,3,23),i=1,7)/5.12,-2.18e-2,-0.24,-0.83,1e3,3e4,
     1 4.7/
      data (CTRecomb(i,4,23),i=1,7)/1.96e-1,-8.53e-3,0.28,-6.46,1e3,3e4,
     1 6.2/
      data (CTRecomb(i,1,24),i=1,7)/7*0./
      data (CTRecomb(i,2,24),i=1,7)/5.27e-1,0.61,-0.89,-3.56,1e3,3e4,
     1 2.89/
      data (CTRecomb(i,3,24),i=1,7)/10.90,0.24,0.26,-11.94,1e3,3e4,
     1 5.4/
      data (CTRecomb(i,4,24),i=1,7)/1.18,0.20,0.77,-7.09,1e3,3e4,6.6/
      data (CTRecomb(i,1,25),i=1,7)/7*0./
      data (CTRecomb(i,2,25),i=1,7)/1.65e-1,6.80e-3,6.44e-2,-9.70,1e3,
     1 3e4,2.04/
      data (CTRecomb(i,3,25),i=1,7)/14.20,0.34,-0.41,-1.19,1e3,3e4,6./
      data (CTRecomb(i,4,25),i=1,7)/4.43e-1,0.91,10.76,-7.49,1e3,3e4,7./
      data (CTRecomb(i,1,26),i=1,7)/7*0./
      data (CTRecomb(i,2,26),i=1,7)/1.26,7.72e-2,-0.41,-7.31,1e3,1e5,
     1 2.56/
      data (CTRecomb(i,3,26),i=1,7)/3.42,0.51,-2.06,-8.99,1e3,1e5,6.3/
      data (CTRecomb(i,4,26),i=1,7)/14.60,3.57e-2,-0.92,-0.37,1e3,3e4,
     1 10./
      data (CTRecomb(i,1,27),i=1,7)/7*0./
      data (CTRecomb(i,2,27),i=1,7)/5.30,0.24,-0.91,-0.47,1e3,3e4,2.9/
      data (CTRecomb(i,3,27),i=1,7)/3.26,0.87,2.85,-9.23,1e3,3e4,6./
      data (CTRecomb(i,4,27),i=1,7)/1.03,0.58,-0.89,-0.66,1e3,3e4,10.51/
      data (CTRecomb(i,1,28),i=1,7)/7*0./
      data (CTRecomb(i,2,28),i=1,7)/1.05,1.28,6.54,-1.81,1e3,1e5,3.0/
      data (CTRecomb(i,3,28),i=1,7)/9.73,0.35,0.90,-5.33,1e3,3e4,5.2/
      data (CTRecomb(i,4,28),i=1,7)/6.14,0.25,-0.91,-0.42,1e3,3e4,10./
      data (CTRecomb(i,1,29),i=1,7)/7*0./
      data (CTRecomb(i,2,29),i=1,7)/1.47e-3,3.51,23.91,-0.93,1e3,3e4,
     1 3.44/
      data (CTRecomb(i,3,29),i=1,7)/9.26,0.37,0.40,-10.73,1e3,3e4,
     1 5.6/
      data (CTRecomb(i,4,29),i=1,7)/11.59,0.20,0.80,-6.62,1e3,3e4,9./
      data (CTRecomb(i,1,30),i=1,7)/7*0./
      data (CTRecomb(i,2,30),i=1,7)/1.00e-5,0.,0.,0.,1e3,3e4,-4.37/
      data (CTRecomb(i,3,30),i=1,7)/6.96e-4,4.24,26.06,-1.24,1e3,3e4,
     1 7.8/
      data (CTRecomb(i,4,30),i=1,7)/1.33e-2,1.56,-0.92,-1.20,1e3,3e4,
     1 11.73/
*
      end
