******************************************************************************
      subroutine he1col
      implicit none
*evaluate collisional rates for helium singlets
      include "WavNKelv.par"
      include "nhe1lvl.par"
      include "TePowers.com"
      include "phe1lv.com"
      include "heclon.com"
      include "c2pson.com"
      include "he1ind.com"
      include "casbhs.com"
      include "hebug.com"
      include "trace.com"
      include "phycon.com"
      include "he1blt.com"
      include "he1crt.com"
      include "he1cbr.com"
      include "he1cin.com"
      include "the1lo.com"
      include "he1stat.com"
      include "He1deltaT.com"
      include "IOqq.com"
*
*     local variables
*
*     free statement labels, >=9
*
      real rcion(9) , r1n(9) , r2n(9)
      integer i , n , iup , j,lo,ihi
      real told,hd,tsq,t3,cs12s,cs12p,hsfac,sum ,f,hdexct
*
      data 
     2  rcion / 1.04e-10,8.24e-9 ,1.08e-7 ,6.61e-7, 3.45E-6,
     2 8.06e-6, 9.47e-5, 2.38e-3, 3.36e-1 /
     3,r1n/3*0., 1.05e-8, 3.45e-9, 1.54e-9, 3.23e-10,2.14E-11,7.09E-14/
     4,r2n/2*0.,7.88e-8,1.14e-8,3.10e-9,1.10e-9,2.0e-10,1.0E-11,2.8E-14/
*
      data told/0./
*
*     define boltz facs between adjacent levels
      do iup=2,nhe1lvl
*       He1deltaTe is array of line temps, upper to lower
*       their boltzmann factors for this temp
        he1bol(iup-1,iup) = exp(-dble(He1deltaTe(iup,iup-1)/te))
      end do
*     this is 1s-2s
      he1bol(1,nhe1lvl+1) = he1bol(1,2)
*
*     the highest level, up to the continuum
      he1cbt(nhe1lvl) = exp( -dble(He1CionTe(nhe1lvl)/te) )
*
*     define remaining Boltzmann factors
      do j=1,nhe1lvl-2
        do i=j+2,nhe1lvl
          he1bol(j,i) = he1bol(j,i-1) * he1bol(i-1,i)
        end do
      end do
      do i=1,nhe1lvl-1
        he1cbt(i) = he1bol(i,nhe1lvl) * he1cbt(nhe1lvl)
      end do
      he1cbt(nhe1lvl+1) = he1cbt(2)
*
*-------------------------------------------------------------
*
*     define HE1LTE(I) = lte population (cm^3) / Ne Np
*     only used in HE1LEV if Te>1000K
*     extra div by 2 due to He+ partition function
      f = 2.0708e-16 / te32 / 2.
      do i=1,nhe1lvl
        if( sngl(he1cbt(i)).gt.1d-70 ) then
*         n.b.; on following two, order is VERY imp fror 32 bit machines
          he1lte(i) = (f /  he1cbt(i) ) * he1stat(i) 
        else
          he1lte(i) = 0.
        endif
      end do
      he1lte(nhe1lvl+1) = he1lte(2) * he1stat(nhe1lvl+1)  / he1stat(2)
*
*-----------------------------------------------------------------------
*     evaluate all needed collisional and rad rates
*     collisions turned off, HD=0
*----------------------------------------------------------------------
*
      if( lgHeClON ) then
         hd = 1.
      else
         hd = 0.
      endif
*     collisional ionization
*     he1clc(1) = rcion(1) * he1cbt(1)*sqrte*hd
*     call colfit(2,2,0,te,he1clc(1) )
*     >>chng 97 mar 19, to new data set for collisional ionization
      call cfit(2,2,te,he1clc(1) )
      he1clc(1) = he1clc(1) * hd
      he1clc(2) = rcion(2) * he1cbt(2)*te10*te10*te10*te01*te01*hd
      he1clc(3) = rcion(3) * he1cbt(3)*te10*te10*hd
      he1clc(4) = rcion(4) * he1cbt(4)*te10*te01*hd
      he1clc(5) = rcion(5) * he1cbt(5)*te01*hd
      he1clc(6) = rcion(6) * he1cbt(6)/te01/te01*hd
      he1clc(7) = rcion(7) * he1cbt(7)/(te10*te03*te03)*hd
      he1clc(8) = rcion(8) * he1cbt(8)/(te10*te10*te10*te03)*hd
      he1clc(9) = rcion(9) * he1cbt(9)/sqrte*hd
*
*     don't reevaluate downward coll if dT/T not large
*     he2cll is zero on very first call since zeroed in block
      if( abs(te-told)/te .lt.0.002 .and.he1cll(2,1).gt.0.) then
         if( lgTrace.and.lgHeBug)
     1   write(qq,'(7X,''HE1COL called-no reval Cul'')')
*        (but still eval col below)
      else
         if( lgTrace ) then
           write(qq,'(7X,''HE1COL called-will reeval Cul'')')
         end if
         told = te
*
         if ( lgC2psOn ) then
*           from Osterbrock's book, fit to 10,000K - 20,000K
*           >>chng 97 july 25, updated to 
*           >>refer Sawey, P.M.J., and Berrington, K.A., 1993, ADNDT 55, 81
            f = min( 26.63, 5.112e-3*te/te10/te01 )
            he1c2p2s = f*8.629e-6 / sqrte / 2.
         else
            he1c2p2s = 0.
         endif
*
         tsq = te  * te
         t3 = tsq * te
*        collision rates for 1-2S, 1-2P, and 1-3 from
*        >>refer Aggarwal, K.M. 1983, MNRAS, 202, 15P
*        >>chng 97 july 25, updated to 
*        >>refer Sawey, P.M.J., and Berrington, K.A., 1993, ADNDT 55, 81
*        if( te.le.25000. ) then
*           cs12s = 0.195 + 1.28e-5*te - 4.69e-10*tsq + 6.19e-15*t3
*           cs12p = 0.335 + 1.45e-5*te + 1.39e-10*tsq - 5.66e-15*t3
*
*        else if( te.gt.25000. .and. te.le.5e5 ) then
*           cs12s = 0.308 + 3.58e-7*te + 6.15e-13*tsq - 1.08e-18*t3
*           cs12p = 0.328 + 1.43e-5*te - 6.55e-12*tsq - 2.69e-18*t3
*
*        else if( te.gt.5e5 ) then
*           cs12s = 0.506
*           cs12p = 5.50
*        endif
*        scale factor to agree with 
*        >>refer Callaway, J., Unnikrishnan, K., & Oza, D.H. 1987,
*        >>refer Phys Rev A, 36, 2576
*        cs12p = cs12p * 0.88
*
*        >>refer Sawey, P.M.J., and Berrington, K.A., 1993, ADNDT 55, 81
         cs12s = min(0.0425 , 9.055e-3*te10*te05 )
*        write(6,*) ' 1-2s', f, cs12s
*        f = cs12p
         cs12p = min(0.0311 , 4.242e-5*sqrte*te02*te02 )
*        write(6,*) ' 1-2p', f, cs12p
*        stop
*
*        C1N is deexcitation rate
*        following is 2P - 1S only
         he1cll(2,1) = cs12p / sqrte * 8.629e-6 / 6. * hd
*        following is 2S - 1S only
         he1c2s1s = cs12s / sqrte * 8.629e-6 / 2. * hd
*
*        option to turn off  collisions frrom ground and n=2
         if( lgCasBhs .or. (hd.eq.0.) ) then
           hsfac = 0.
         else
           hsfac = 1.
         endif
*
*        HE1CLL(u,l) is de-excitation rate from u to l
*        rate coef from Callaway et al. preprint
         he1cll(3,1) = 1.4e-9 * hsfac
*        rate from i to both 2s and 2p
         he1cll(3,2) = (3.39*te10*te10*te10/te01/te01/te01) / sqrte *
     1   8.629e-6 / 18. * hsfac
*
         do ihi=4,nhe1lvl
            he1cll(ihi,1) = r1n(ihi) / sqrte * hsfac
*           different temp denpendence is not a bug
            he1cll(ihi,2) = r2n(ihi) * hsfac
            do lo=3,ihi-1
              he1cll(ihi,lo) = hdexct(ihi,lo) * hd
            end do
         end do
*
*
         if( lgTrace.and.lgHe1Bug ) then
            write(qq,'(7X,''HE1COL rate n->n-1:'',1P,8E10.3,'' 2S1'',
     1      e9.2)') (he1cll(i+1,i),i=1,8),he1c2s1s
            write(qq,'(7X,''HE1COL col ion cof:'',1P,9E10.3)') he1clc
            write(qq,'(7X,''HE1COL rate down 1:'',1P,9E10.3)') 
     1      (he1cll(i,1),i=1,9)
            write(qq,'(7X,''HE1COL rate down 2:'',1P,9E10.3)')
     1      (he1cll(i,2),i=1,9)
            write(qq,'(7X,''HE1COL rate down 3:'',1P,9E10.3)')
     1      (he1cll(i,3),i=1,9)
            write(qq,'(7X,''HE1COL rate down 4:'',1P,9E10.3)')
     1      (he1cll(i,4),i=1,9)
            write(qq,'(7X,''HE1COL rate down 5:'',1P,9E10.3)')
     1      (he1cll(i,5),i=1,9)
            write(qq,'(7X,''HE1COL boltz fac c:'',1P,9E10.3)') he1cbt
            write(qq,'(7X,''HE1COL HE1LTE(i):  '',1P,10E10.3)') he1lte
            write(qq,'(7X,''he1col       c2p2s='',1p,e10.3)') he1c2p2s
         endif
      endif
*
      IF( he1lte(1).gt.0. ) THEN
*     following are eden independent, used in hlevel
      he1coldn(1) = (he1cll(2,1)*he1lte(2) + he1c2s1s*he1lte(10) +
     1 he1cll(3,1)*he1lte(3) + he1cll(4,1)*he1lte(4) +
     2 he1cll(5,1)*he1lte(5) + he1cll(6,1)*he1lte(6) +
     3 he1cll(7,1)*he1lte(7) +he1cll(8,1)*he1lte(8) +
     4 he1cll(9,1)*he1lte(9) ) / he1lte(1) 
*
*     SUM is total rate from high states to both 2s and 2p
      sum = (he1cll(3,2)*he1lte(3) + he1cll(4,2)*he1lte(4) +
     1 he1cll(5,2)*he1lte(5) + he1cll(6,2)*he1lte(6) +
     2 he1cll(7,2)*he1lte(7) + he1cll(8,2)*he1lte(8) + 
     3 he1cll(9,2)*he1lte(9) ) / ( he1lte(2) + he1lte(10) )
*
*     HE1CLL(2,1) is 2p - 1s rate; c2s1s is 2s - 1s rate
      he1coldn(2) = sum + he1cll(2,1)
      he1coldn(10) = sum + he1c2s1s
*
      he1coldn(3) = he1cll(3,1) + he1cll(3,2) + (he1cll(4,3)*he1lte(4) +
     1 he1cll(5,3)* he1lte(5) + he1cll(6,3)*he1lte(6) +
     2 he1cll(7,3)*he1lte(7) + he1cll(8,3)*he1lte(8) +
     3 he1cll(9,3) *he1lte(9) ) /he1lte(3)
*
      he1coldn(4) = he1cll(4,1) + he1cll(4,2) + he1cll(4,3) +
     1 (he1cll(5,4)*he1lte(5) + he1cll(6,4)*he1lte(6) +
     2 he1cll(7,4)*he1lte(7) + he1cll(8,4)*he1lte(8) +
     3 he1cll(9,4)*he1lte(9) ) / he1lte(4)
*
      he1coldn(5) = (he1cll(6,5)*he1lte(6) + he1cll(7,5)*he1lte(7) +
     1 he1cll(8,5)*he1lte(8) + he1cll(9,5)*he1lte(9)) /he1lte(5) +
     2 he1cll(5,1) + he1cll(5,2) + he1cll(5,3) + he1cll(5,4)
*
      he1coldn(6) = he1cll(6,1) + he1cll(6,2) + he1cll(6,3)+he1cll(6,4)+
     1 he1cll(6,5) + ( he1cll(7,6)*he1lte(7) + he1cll(8,6)*he1lte(8) +
     2 he1cll(9,6)*he1lte(9) ) /he1lte(6)
*
      he1coldn(7) = he1cll(7,1) + he1cll(7,2) + he1cll(7,3)+he1cll(7,4)+
     1 he1cll(7,5) + he1cll(7,6) + ( he1cll(8,7)*he1lte(8) +
     2 he1cll(9,7)*he1lte(9) ) /he1lte(7)
*
      he1coldn(8) = he1cll(8,1) + he1cll(8,2) + he1cll(8,3) +he1cll(8,4)
     1 + he1cll(8,5) + he1cll(8,6) + he1cll(8,7) +
     2 he1cll(9,8)*he1lte(9)/he1lte(8)
*
      he1coldn(9) = he1cll(9,1) + he1cll(9,2) + he1cll(9,3)+he1cll(9,4)
     1       + he1cll(9,5) + he1cll(9,6) + he1cll(9,7) +he1cll(9,8) 
*
      if( lgTrace.and.lgHe1Bug ) then
         write(qq,'(7X,''HE1CLL he1coldn(i)      '',1P,10E10.3)')
     1   (he1coldn(i),i=1,10)
      endif
      else
        do n=1,nhe1lvl
          he1coldn(n) = 0.
        end do
      endif
*
      end
