******************************************************************************
      real function HydColIon(n,iz)
      implicit none
*calculate hydrogenic ionization rates for all n, and Z
*     Allen 1973, Astro. Quan. for low Te.
*     Sampson and Zhang 1988, ApJ, 335, 516 for High Te.
*
      integer n,iz
      include "phycon.com"
      include "IOqq.com"
*
*     local variables
      real tev,rate,xn,ryd,y,chim,rate2
      real e1,e2,e3,t1,t2,t3,t4
      real ee1,sexp , small
      integer i
      real arrH(4),arrRnp(8),arrg(10),H,Rnp,g
      data (arrH(i),i=1,4)/1.48,3.64,5.93,8.32/
      data (arrRnp(i),i=1,8)/2.20,1.90,1.73,1.65,1.60,1.56,1.54,1.52/
      data (arrg(i),i=1,10)/0.8675,0.932,0.952,0.960,0.965,0.969,
     1      0.972,0.975,0.978,0.981/
*     data small/1e-37/
      data small/0./
*
*begin sanity check
      if( iz.lt.2 .or. n.le.0 ) then
        write(qq,'(''HydColIon called with impossible parameters.'')')
        write(qq,'(3i5)') n,iz
        stop
      endif
*end sanity check
*
      if(n.gt.4) then
        H = 2.15 * n
      else
        H = arrH(n)
      endif
      if(n.gt.8) then
        Rnp = 1.52
      else
        Rnp = arrRnp(n)
      endif
      if(n.gt.10) then
        g = arrg(10)
      else
        g = arrg(n)
      endif
*
      tev = 8.617e-5 * te
      ryd = 13.60583
      xn = float(n)
      chim = iz**2 * ryd / xn / xn
      y = chim / tev
*     E1(x) integral must be multiplied by e(-y) if y>1.
      if(y.lt.1.) then
        e1 = ee1(y)
      else
        e1 = ee1(y)*sexp(y)
      endif
      e2 = sexp(y) - y*e1
      e3 = ( sexp(y) - y*e2 )/2.
*
      t1 = 1/xn * e1
      t2 = 1./3./xn * (sexp(y) - y*e3)
      t3 = 3.*H/xn/(3.-Rnp) * ( y*e2 - 2.*y*e1 + sexp(y) )
      t4 = 3.36*y*(e1 - e2)
      rate = 7.69415e-9 * sqrt(tev) * (xn/iz)**4 * g * y 
      rate = rate * (t1 - t2 + t3 + t4)
      rate = max( rate , small )
*
*     rate from Allen:
      if(iz.eq.1) then
        rate2 = 1.1e-8 * sqrt(te) /chim/chim * 
     1          sexp(log(10.)*5040.*chim/te)
      else
        rate2 = 2.1e-8 * sqrt(te) /chim/chim * 
     1          sexp(log(10.)*5040.*chim/te)
      endif
      rate2 = max( rate2 , small )
*
*     Take the lowest of the two, they fit nicely together...
      HydColIon = min(rate,rate2)
*
      end 
