******************************************************************************
      subroutine HydroCool
      implicit none
*compute net heating/cooling due to model hydrogen atom
      include "nhlvl.par"
      include "ncell.par"
      include "limelm.par"
      include "te1ryd.par"
      include "en1ryd.par"
      include "itrdim.par"
      include "hem.com"
      include "ffheat.com"
      include "TePowers.com"
      include "phlevl.com"
      include "freeon.com"
      include "hlvcol.com"
      include "hstat.com"
      include "phycon.com"
      include "h.com"
      include "HdeltaT.com"
      include "dcool.com"
      include "heating.com"
      include "logte.com"
      include "hex.com"
      include "HPhoto.com"
      include "dtrans.com"
      include "hcolrt.com"
      include "telogn.com"
      include "coolng.com"
      include "teinv.com"
      include "tff.com"
      include "HPHeat.com"
      include "HFBNet.com"
      include "HLineTot.com"
      include "ZoneCnt.com"
      include "IOqq.com"
*
*     local variables
      double precision temp
      real dhrest , hlone(lmhlvl) , edhii , brems , hclf ,hsave,coolfac,
     1 RecCool , hold, sexp , factor , drestly , dbarest ,dhone(lmhlvl),
     2 dcoola
      integer i , iu , n , l
*
*     compute the total cooling due to the hydrogen atom, and its derivative
*     halfte is 1/(2T)
*
      edhii = eden * hii
*
*     lyman alpha cooling - total cooling is net rad loss
      coola = edhii * 1.636e-11 *
     1 ( hn(1)*hlbolt(1,2)*(hc2s1s + 3.*hcol(2,1)) 
     1 - hn2s*hc2s1s - hn2p*hcol(2,1) )
      if( coola.gt.0. ) then
*       net coolant, exponential dominates deriv
        dcoola = coola * (1.184e5 * tsq1 - halfte )
      else
*       net heating, te^-1/2 dominates
        dcoola = -coola * halfte
      endif
*     above, first line cooling, second heating
*
*     Lyman line collisional heating/cooling
      drestly = 0.
      restly = 0.
      do i=3,nhlvl-1
        hlone(i) = hcol(i,1) * (hn(1)*hlbolt(1,i)*float(i*i) -hn(i))*
     1  edhii* en1ryd*( 1. - 1./(i**2) )
        restly = restly + hlone(i)
        if( hlone(i) .gt.0. ) then
          drestly = drestly + hlone(i)*(HdeltaTe(i,1)*tsq1-halfte)
        else
          drestly = drestly -hlone(i)* halfte
        endif
      end do
*
*     all remaining hydrogen lines
      hrest = 0.
      dhrest = 0.
      do l=3,nhlvl-2
        do iu=l+1,nhlvl-1
          hlone(i) = 
     1    hcol(iu,l)*(hn(l)*hlbolt(l,iu)*hstat(iu)/hstat(l)-hn(iu))*
     2    edhii* (1.384e-16* HdeltaTe(iu,l) )
          hrest = hrest + hlone(i)
          if( hlone(i) .gt.0. ) then
            dhrest = dhrest + hlone(i)*(HdeltaTe(iu,1)*tsq1-halfte)
          else
            dhrest = dhrest - hlone(i)*halfte
          endif
        end do
      end do
*
*     Balmer line collisional heating/cooling and derivative
      barest = 0.
      dbarest = 0.
      do i=3,nhlvl-1
        hlone(i) = hcol(i,2) * (hn(2)*hlbolt(2,i)*float(i*i)/4. -hn(i))*
     1  edhii* en1ryd*( 1./4. - 1./(i**2) )
        barest = barest + hlone(i)
*       count boltzmann factor from ground - not a typo
        if( hlone(i) .gt.0. ) then
*         coolant
          dhone(i) = hlone(i)*(HdeltaTe(i,1)*tsq1-halfte)
        else
*         heating agent
          dhone(i) = -hlone(i)*halfte
        endif
        dbarest = dbarest + dhone(i)
      end do
*
*     this is total hydrogen line cooling or heating
      HLineTotCool = coola + restly +  barest + hrest 
*
*     above can be either heating or coolant
*     must add this to total heating or cooling, as appropriate
      if( HLineTotCool.gt.0. ) then
*       hydrogen is a net coolant
        heating(1,24) = 0.
        call coladd('Hlin' , 0 , HLineTotCool )
        dCooldT = dCooldT + dcoola + drestly + dhrest + dbarest
        dHLTot = 0.
      else
*       hydrogen is a net heat source
        heating(1,24) = -HLineTotCool
        call coladd('Hlin' , 0 , 0. )
        dHLTot = -dcoola - drestly - dbarest - dhrest
      endif
*665  write(6,'('' chydro'',1p,e10.3,9e10.2)')te, HLineTotCool, coola ,
*    1 restly , barest , hrest 
*666  write(6,'('' dhydro'',1p,e10.3,9e10.2)') 
*    1te, dHLTot , dcoola , drestly,dbarest,dhrest
*
*     hydrogen collisional ionization and H-3 body heating, net cooling
*     HEX and dHEXdt are evaluated in HLEVEL
*     HEX is collisional ionization cooling less three body rec heating
      chion = hex * hii
      call coladd( 'Hion' ,  0 , max(0.,chion) )
      dCooldT = dCooldT + dhexdt * hii
*     heating(1,4) is all three body heating, opposite of coll ion cooling
      heating(1,4) = max(0., -chion )
*
*     Hydrogen brems free free cooling, free-free heating
      factor = 0.9 + 1.2/(2.2+abs(alogte-5.398))
*     >>chng 96 jan 8, for stability always use corrected free free
      brems = 1.42e-27 * eden * sqrte * factor * sexp(tff*te1ryd/te)
      temp = brems
*666  write(6,'(1p,9e10.2)') hbrems , brems , hii
*     lgFreeOn usually TRUE, set false with no free free command
	if( lgFreeOn ) then
         hbrems = temp * hii
	else
         hbrems = 0.
	endif
*     TFF is freq (Ryd) where gas becomes optically thin to absorption
*     if( chDffTrns.eq.'OTS' ) then
*       ots continuum transport - do not count optically thick part
*       brems = 1.42e-27 * eden * sqrte * factor * sexp(tff*te1ryd/te)
*     else if( chDffTrns(1:2).eq.'OU' ) then
*       brems = 1.42e-27 * eden * sqrte * factor
*     else
*       write(qq,'('' COOLR: insane chDffTrns='',a3)') chDffTrns
*       stop
*     endif
*     these two terms are both large, nearly canceling, near lte
      HFFNet = hbrems - FreeFreeHeat
*     >>chng 96 oct 30, from HFFNet to just hbrems,
*     since SumHeat picks up FreeFreeHeat
      dCooldT = dCooldT +  hbrems * halfte
      call coladd( 'H ff' ,  0 , max(0.,HFFNet)  )
      heating(1,12) = max(0.,-HFFNet )
*
*     hydrogen recombination free-bound free bound cooling
*     this is ground, not ncluded in case b sum
      hrecem = hclf(1)  * hrec(1,2)
      hsave = 0.
*     in this loop hclf(2) is both 2s and 2p
      do n=2,nhlvl-1
*       this is optically thin sum of cooling, will subtract from case b sum
*       so that we can "top off" the model atom's cooling
        hsave = hsave + hclf(n)
        hrecem = hrecem + hclf(n)  * hrec(n,2)
      end do
*
*     following is expression for case b sum of cooling
      coolfac = 
     1 (-25.859117 + 0.16229407*telogn(1) + 0.34912863*telogn(2) 
     2 - 0.10615964*telogn(3)) /
     3 (1.+ 0.050866793*telogn(1) - 0.014118924*telogn(2) 
     4 + 0.0044980897*telogn(3) + 6.0969594E-5*telogn(4) )
      RecCool = (10.**coolfac)/te - hsave
*     let it be as much as 1% negative
      if(RecCool/hsave.lt.-.02) then
        write(qq,'('' RecCool lt 0 in HydroCool, frac error='',1p,
     1  e10.2)') RecCool/hsave
*       set it to a small positive value
        RecCool = 0.01 * hsave
      endif
      hrecem = hrecem + RecCool  * hrec(nhlvl,2)
*     this is now total free-bound cooling
      hrecem = hrecem * edhii
*
*     heating by ground of hydrogen
      heating(1,1) = hii*hn(1) * HPhotHeat(1)
*     units of heating (and cooling) are ergs/s/cm^3
*   
*     photoionization of n=2, to next to highest level
*     HPhotHeat(n) is photoionization heating due to level n,
*     evaluated in routine hydrgn
      HeatExc = HPhotHeat(2) *hii*hn(2)
      do i=3,nhlvl-1
        HeatExc = HeatExc + hii*hn(i)*HPhotHeat(i)
      end do
*     following is net cooling due to two processes
*     recombination cooling less photoionization heating
      HFreBndNet = hrecem - HeatExc
*     write(qq,'(1p,'' HFreBndNet'',i4,1p,9e10.2)')nzone,
*    1 HFreBndNet,hrecem,HeatExc
*
*     heating(1,2) is all excited state photoionization heating
*     >>chng 96 jan 25, was -HeatExc 
      heating(1,2) = max(0.,-HFreBndNet )
      call coladd( 'H FB' ,  0 , max(0.,HFreBndNet ) )
*
*     if rec coef goes as T^-.8, but times T, so propto t^.2
      dCooldT = dCooldT + 0.2*HFreBndNet*teinv
*
*     hydrogen induced recombination cooling
      crcind = cinduc(nhlvl+1)*edhii
      dCooldT = dCooldT + crcind*(1.58e5*teinv-1.5)*teinv
      do i=1,nhlvl-1
        hold = cinduc(i) * edhii
        crcind = crcind + hold
        dCooldT = dCooldT + hold*(1.58e5/(i*i*te) - 1.5 ) * teinv
      end do
      call coladd( 'Hind' ,  0 , crcind )
*
      end
