      subroutine LineFit(t,r)
      implicit none
*effective recombination coefficients for lines of C, N, O, by D. Verner
* Version 2, April 30, 1997
******************************************************************************
*** This subroutine calculates effective recombination coefficients
*** for 110 permitted recombination lines of C, N, O (Pequignot, Petitjean,
*** & Boisson, 1991, A&A, 251, 680) and 405 permitted dielectronic 
*** recombination lines (Nussbaumer & Storey, 1984, A&AS, 56, 293)
*** Input parameter:   t  - temperature, K
*** Output parameters: r(i,j), i=1,471
***                    r(i,1) - atomic number
***                    r(i,2) - number of electrons
***                    r(i,3) - wavelength, angstrom
***                    r(i,4) - rate coefficient, cm^3 s^(-1)
******************************************************************************
      integer i,j,j1,j2
      real t
      real r(471,4),rr(110,4),dr(405,4)
      real P,ST
      real z,te,p1,p2,p3,p4,p5,p6,a1,a,x
      integer ip(38),id(38),jd(6)
      common/P/P(110,8)
      common/ST/ST(405,9)
      data jd/143,145,157,360,376,379/
      data ip/7,9,12,13,14,16,18,19,20,21,22,44,45,49,50,52,53,54,55,
     *56,57,58,59,60,66,67,78,83,84,87,88,95,96,97,100,101,103,104/
      data id/7,3,10,27,23,49,51,64,38,47,60,103,101,112,120,114,143,
     *145,157,152,169,183,200,163,225,223,237,232,235,249,247,300,276,
     *278,376,360,379,384/
      do i=1,110
         rr(i,1)=P(i,1)
         rr(i,2)=P(i,2)
         rr(i,3)=P(i,3)
         z=P(i,1)-P(i,2)+1.0
         te=1.0e-04*t/z/z
         p1=P(i,4)
         p2=P(i,5)
         p3=P(i,6)
         p4=P(i,7)
         if(te.lt.0.004)then
            a1=p1*0.004**p2/(1.0+p3*0.004**p4)
            a=a1/sqrt(te/0.004)
         else
            if(te.gt.2.0)then
               a1=p1*2.0**p2/(1.0+p3*2.0**p4)
               a=a1/(te/2.0)**1.5
            else
               a=p1*te**p2/(1.0+p3*te**p4)
            endif
         endif
         rr(i,4)=1.0e-13*z*a*P(i,8)
      end do
      do i=1,405
         dr(i,1)=ST(i,1)
         dr(i,2)=ST(i,2)
         dr(i,3)=ST(i,3)
         te=1.0e-04*t
         p1=ST(i,4)
         p2=ST(i,5)
         p3=ST(i,6)
         p4=ST(i,7)
         p5=ST(i,8)
         p6=ST(i,9)
         if(te.lt.p6)then
            x=p5*(1.0/te-1.0/p6)
            if(x.gt.80.0)then
               a=0.0
            else
               a1=(p1/p6+p2+p3*p6+p4*p6*p6)/p6**1.5/exp(p5/p6)
               a=a1/exp(x)
            endif
         else
            if(te.gt.6.0)then
               a1=(p1/6.0+p2+p3*6.0+p4*36.0)/6.0**1.5/exp(p5/6.0)
               a=a1/(te/6.0)**1.5
            else
               a=(p1/te+p2+p3*te+p4*te*te)/te**1.5/exp(p5/te)
            endif
         endif
         dr(i,4)=1.0e-12*a
      end do
      do i=1,6
         j1=jd(i)
         j2=j1+1
         dr(j1,4)=dr(j1,4)+dr(j2,4)
         dr(j2,1)=0.0
      end do
      do i=1,38
         j1=ip(i)
         j2=id(i)
         rr(j1,4)=rr(j1,4)+dr(j2,4)
         dr(j2,1)=0.0
      end do
      do i=1,110
         r(i,1)=rr(i,1)
         r(i,2)=rr(i,2)
         r(i,3)=rr(i,3)
         r(i,4)=rr(i,4)
      end do
      j=110
      do i=1,405
         if(dr(i,1).gt.1.0)then
            j=j+1
            r(j,1)=dr(i,1)
            r(j,2)=dr(i,2)
            r(j,3)=dr(i,3)
            r(j,4)=dr(i,4)
         endif
      end do
      return
      end
