***********************************************************************
       subroutine oi3Pcs(cs21,cs20,cs10)
       implicit none
       real cs21, cs20, cs10
*      make collision strengths with electrons for 3P O I ground term.
*      >>refer Berrington, K.A. 1988, J.Phys.B, 21, 1083 for Te > 3000K
*      >>refer Bell, Berrington & Thomas 1998, MNRAS 293, L83 for 50K <= Te <= 3000K
*      numbers in cs variables refer to j value: j=0,1,2 (n=3,2,1 in 5 level atom)
*      written by Kirk Korista, 29 may 96
*      adapted by Peter van Hoof, 30 march 99 (include Bell et al. data)
*     all data above 3000K have been adjusted down by a constant factor to make
*     them line up with Bell et al. data.
*
       include "TePowers.com"
       include "phycon.com"
*      local variables
       real a,b,c,d
*
* 3P2 - 3P1
       if( te.le.3.0e3 ) then
         cs21 = 1.49e-4*sqrte/te02/te02
       else if( te.le.1.0e4 ) then
         a = -5.5634127e-04
         b = 8.3458102e-08
         c = 2.3068232e-04
         cs21 = 0.228*(a + b*te32 + c*sqrte)
       else
         cs21 = 0.228*min(0.222, 5.563e-06*te*te05*te02)
       endif
*
* 3P2 - 3P0
       if( te.le.3.0e3 ) then
         cs20 = 4.98e-5*sqrte
       else if( te.le.1.0e4 ) then
         a = -3.7178028e-04
         b = 2.0569267e-08
         c = 1.1898539e-04
         cs20 = 0.288*(a + b*te32 + c*sqrte)
       else
         cs20 = 0.288*min(0.0589, 1.015e-05*te/te10/te02/te005)
       endif
*
* 3P1 - 3P0
       if( te.le.3.0e3 ) then
         cs10 = 1.83e-9*te*te30*te05
       else if( te.le.1.0e4 ) then
         a = -5.9364373e-04
         b = 0.02946867
         c = 10768.675
         d = 3871.9826
         cs10 = 0.0269*(a + b*exp(-0.5*((te-c)/d)**2))
       else
         cs10 = 0.0269*min(0.074, 7.794e-08*te32/te10/te01)
       endif
*
       end
