******************************************************************************
      subroutine plwcon( chCard )
      implicit none
*parse the power law continuum command
      character chCard*80
*
      include "limspc.par"
      include "sptype.com"
      include "spec.com"
      include "nvary.com"
      include "limext.par"
      include "limpar.par"
      include "vformt.com"
      include "vparm.com"
      include "nvfpnt.com"
      include "varon.com"
      include "ninput.com"
      include "IOqq.com"
*
*     local variables
      logical lgEOL , lgMatch
      integer i
      real fread
*
*     power law with cutoff and X-ray continuum
*
      nspec = nspec + 1
      if( nspec.gt.limspc ) then
        write(qq,'('' Too many continua entered; increase LIMSPC'')')
        stop
      endif
*
      chSpType(nspec) = 'POWER'
*
*     first parameter is slope of continuum, probably should be negative
      i = 5
      slope(nspec) = fread( chCard , i , 76 , lgEOL )
      if( lgEOL ) then
        write(qq,'('' There should have been a number on this '',
     1  ''line.   Sorry.'')')
        stop
      endif
*
      if( slope(nspec).ge.0. ) then
        write(qq,'('' Is the slope of this power law correct?'')')
      endif
*
*     second optional parameter is high energy cut off
      cutoff(nspec,1) = fread( chCard , i , 76 , lgEOL )
*     no cutoff if eof hit
      if( lgEOL ) then
*       no extra parameters at all, so put in extreme cutoffs
        cutoff(nspec,1) = 1e4
        cutoff(nspec,2) = 1e-4
      else
*       first cutoff was present, check for second
        cutoff(nspec,2) = fread( chCard , i , 76 , lgEOL )
        if(lgEOL) cutoff(nspec,2) = 1e-4
      endif
*
*     check that energies were entered in the correct order
      if( cutoff(nspec,2).gt.cutoff(nspec,1) ) then
        write(qq,'('' The optional cutoff energies do not appear'',
     1  '' to be in the correct order.  Check Hazy.'')')
        stop
      endif
*
*     check for keywork KELVIN to interprete cutoff energies as degrees
      if( lgMatch( 'KELV' , chCard ) ) then
*       temps are log if first le 10
        if( cutoff(nspec,1).le.10.)cutoff(nspec,1)=10.**cutoff(nspec,1)
        if( cutoff(nspec,2).le.10.)cutoff(nspec,2)=10.**cutoff(nspec,2)
        cutoff(nspec,1) = cutoff(nspec,1) / 1.5789e5 
        cutoff(nspec,2) = cutoff(nspec,2) / 1.5789e5 
      endif
*
      if( cutoff(nspec,1).lt.0. .or. cutoff(nspec,2).lt.0. ) then
        write(qq,'('' A negative cutoff energy is not physical.  '',
     1  ''Sorry.'')')
        stop
      endif
*
      if( cutoff(nspec,2).eq.0. .and. slope(nspec).le.-1. )
     1 write(qq,'('' A power-law with this slope, and no low energy'',
     2'' cutoff, may have an unphysically large''/
     3'' brightness temperature in the radio.'')')
*
*     vary option
      if( lgVarOn ) then
        nparm = nparm + 1
*       pointer to where to write
        nvfpnt(nparm) = nRead
        if( lgMatch('ARYB',chCard) ) then
*         this test is for key "varyb", meaning to vary second parameter
*         the cutoff temperature
*         this is the number of parameters to feed onto the input line
          nvarxt(nparm) = 2
*         vary ??
          write(chVarFmt(nparm),'(''(''''POWER LAW'',F10.4,'' KELVIN'''',
     12F10.5)'')') slope(nspec)
*         param is linear scale factor
          vparm(nparm,1) = log10( cutoff(nspec,1)*1.5789e5)
          vparm(nparm,2) = log10( cutoff(nspec,2)*1.5789e5)
          vincr(nparm) = 0.2
        else if( lgMatch('ARYC',chCard) ) then
*         the keyword wsa "varyc"
*         this is the number of parameters to feed onto the input line
          nvarxt(nparm) = 1
*         vary ??
          write(chVarFmt(nparm),
     1    '(''(''''POWER LAW'',2F10.4,'' KELVIN'''',F10.5)'')')
     2    slope(nspec) , log10( cutoff(nspec,1)* 1.5789E5)
*         
          vparm(nparm,1) = log10( cutoff(nspec,2)*1.5789e5)
          vincr(nparm) = 0.2
        else 
*         vary the first parameter only, but still are two more
*         this is the number of parameters to feed onto the input line
          nvarxt(nparm) = 3
          write(chVarFmt(nparm),
     1    '(''(''''POWER LAW KELVIN'''',3F15.5)'')')
*         param is slope of the power law
          vparm(nparm,1) = slope(nspec)
          vparm(nparm,2) = log10( cutoff(nspec,1)*1.5789e5)
          vparm(nparm,3) = log10( cutoff(nspec,2)*1.5789e5)
          vincr(nparm) = 0.2
        endif
      endif
*
      end
