      subroutine rrfit(iz,in,t,r)
*** Version 4. June 29, 1999.
*** Written by D. A. Verner, verner@pa.uky.edu 
******************************************************************************
*** This subroutine calculates rates of radiative recombination for all ions
*** of all elements from H through Zn by use of the following fits:
*** H-like, He-like, Li-like, Na-like - Verner & Ferland, 1996, ApJS, 103, 467
*** Other ions of C, N, O, Ne - Pequignot et al. 1991, A&A, 251, 680,
***    refitted by Verner & Ferland formula to ensure correct asymptotes
*** Fe XVII-XXIII - Arnaud & Raymond, 1992, ApJ, 398, 394
*** Fe I-XV - refitted by Verner & Ferland formula to ensure correct asymptotes
*** Other ions of Mg, Si, S, Ar, Ca, Fe, Ni - 
***                      - Shull & Van Steenberg, 1982, ApJS, 48, 95
*** Other ions of Na, Al - Landini & Monsignori Fossi, 1990, A&AS, 82, 229
*** Other ions of F, P, Cl, K, Ti, Cr, Mn, Co (excluding Ti I-II, Cr I-IV,
*** Mn I-V, Co I)        - Landini & Monsignori Fossi, 1991, A&AS, 91, 183
*** All other species    - interpolations of the power-law fits
*** Input parameters:  iz - atomic number 
***                    in - number of electrons from 1 to iz 
***                    t  - temperature, K
*** Output parameter:  r  - rate coefficient, cm^3 s^(-1)
******************************************************************************
      implicit none
      real rrec,rnew,fe,t,r,tt
      integer iz,in
      common/rrec/rrec(2,30,30)
      common/rnew/rnew(4,30,30)
      common/ferr/fe(3,13)
      r=0.0
      if(iz.lt.1.or.iz.gt.30)then
         write(6,'('' rrfit called with insane atomic number, ='',i4
     &   )') iz
         stop
      endif
      if(in.lt.1.or.in.gt.iz)then
         write(6,'('' rrfit called with insane number elec ='',i4
     &   )') in
        stop
      endif
      if(in.le.3.or.in.eq.11.or.(iz.gt.5.and.iz.lt.9).or.iz.eq.10.or.
     &(iz.eq.26.and.in.gt.11))then         
         tt=sqrt(t/rnew(3,iz,in))
         r=rnew(1,iz,in)/(tt*(tt+1.0)**(1.0-rnew(2,iz,in))*
     &        (1.0+sqrt(t/rnew(4,iz,in)))**(1.0+rnew(2,iz,in)))
      else
         tt=t*1.0e-04
         if(iz.eq.26.and.in.le.13)then
            r=fe(1,in)/tt**(fe(2,in)+fe(3,in)*log10(tt))
         else
            r=rrec(1,iz,in)/tt**rrec(2,iz,in)
         endif
      endif
      return 
      end
*********************************************
      block data radrec
      implicit none
      real rrec,rnew,fe
      common/rrec/rrec(2,30,30)
      common/rnew/rnew(4,30,30)
      common/ferr/fe(3,13)
	integer i
      data(rrec(i, 4, 4),i=1,2)/4.500e-13,0.6480/
      data(rrec(i, 5, 4),i=1,2)/2.680e-12,0.7250/
      data(rrec(i, 6, 4),i=1,2)/4.900e-12,0.8030/
      data(rrec(i, 7, 4),i=1,2)/9.400e-12,0.7650/
      data(rrec(i, 8, 4),i=1,2)/1.590e-11,0.7590/
      data(rrec(i, 9, 4),i=1,2)/1.919e-11,0.7849/
      data(rrec(i,10, 4),i=1,2)/2.800e-11,0.7710/
      data(rrec(i,11, 4),i=1,2)/4.030e-11,0.7873/
      data(rrec(i,12, 4),i=1,2)/6.830e-11,0.7650/
      data(rrec(i,13, 4),i=1,2)/8.343e-11,0.8291/
      data(rrec(i,14, 4),i=1,2)/1.430e-10,0.8230/
      data(rrec(i,15, 4),i=1,2)/1.460e-10,0.8391/
      data(rrec(i,16, 4),i=1,2)/2.000e-10,0.8060/
      data(rrec(i,17, 4),i=1,2)/2.091e-10,0.8691/
      data(rrec(i,18, 4),i=1,2)/3.070e-10,0.8190/
      data(rrec(i,19, 4),i=1,2)/3.210e-10,0.8934/
      data(rrec(i,20, 4),i=1,2)/4.610e-10,0.8330/
      data(rrec(i,21, 4),i=1,2)/4.870e-10,0.8060/
      data(rrec(i,22, 4),i=1,2)/5.139e-10,0.7781/
      data(rrec(i,23, 4),i=1,2)/5.850e-10,0.7570/
      data(rrec(i,24, 4),i=1,2)/6.556e-10,0.7359/
      data(rrec(i,25, 4),i=1,2)/7.238e-10,0.7242/
      data(rrec(i,27, 4),i=1,2)/8.404e-10,0.7167/
      data(rrec(i,28, 4),i=1,2)/1.360e-09,0.8420/
      data(rrec(i,29, 4),i=1,2)/1.880e-09,0.8420/
      data(rrec(i,30, 4),i=1,2)/2.400e-09,0.8420/
      data(rrec(i, 5, 5),i=1,2)/4.600e-13,0.6360/
      data(rrec(i, 6, 5),i=1,2)/2.300e-12,0.6450/
      data(rrec(i, 7, 5),i=1,2)/5.000e-12,0.6760/
      data(rrec(i, 8, 5),i=1,2)/9.600e-12,0.6700/
      data(rrec(i, 9, 5),i=1,2)/1.558e-11,0.6816/
      data(rrec(i,10, 5),i=1,2)/2.300e-11,0.7040/
      data(rrec(i,11, 5),i=1,2)/3.253e-11,0.7075/
      data(rrec(i,12, 5),i=1,2)/4.600e-11,0.7110/
      data(rrec(i,13, 5),i=1,2)/5.951e-11,0.7125/
      data(rrec(i,14, 5),i=1,2)/7.700e-11,0.7140/
      data(rrec(i,15, 5),i=1,2)/1.042e-10,0.7330/
      data(rrec(i,16, 5),i=1,2)/1.400e-10,0.7550/
      data(rrec(i,17, 5),i=1,2)/1.760e-10,0.7682/
      data(rrec(i,18, 5),i=1,2)/2.140e-10,0.7740/
      data(rrec(i,19, 5),i=1,2)/2.629e-10,0.7772/
      data(rrec(i,20, 5),i=1,2)/3.240e-10,0.7800/
      data(rrec(i,21, 5),i=1,2)/3.970e-10,0.7840/
      data(rrec(i,22, 5),i=1,2)/4.700e-10,0.7873/
      data(rrec(i,23, 5),i=1,2)/5.500e-10,0.7910/
      data(rrec(i,24, 5),i=1,2)/6.301e-10,0.7952/
      data(rrec(i,25, 5),i=1,2)/7.058e-10,0.7982/
      data(rrec(i,27, 5),i=1,2)/8.252e-10,0.8004/
      data(rrec(i,28, 5),i=1,2)/8.710e-10,0.8000/
      data(rrec(i,29, 5),i=1,2)/9.170e-10,0.8000/
      data(rrec(i,30, 5),i=1,2)/9.630e-10,0.7990/
      data(rrec(i, 6, 6),i=1,2)/4.700e-13,0.6240/
      data(rrec(i, 7, 6),i=1,2)/2.200e-12,0.6390/
      data(rrec(i, 8, 6),i=1,2)/5.100e-12,0.6600/
      data(rrec(i, 9, 6),i=1,2)/9.171e-12,0.6757/
      data(rrec(i,10, 6),i=1,2)/1.500e-11,0.6840/
      data(rrec(i,11, 6),i=1,2)/2.191e-11,0.6875/
      data(rrec(i,12, 6),i=1,2)/3.200e-11,0.6910/
      data(rrec(i,13, 6),i=1,2)/4.308e-11,0.6970/
      data(rrec(i,14, 6),i=1,2)/5.800e-11,0.7030/
      data(rrec(i,15, 6),i=1,2)/7.316e-11,0.7027/
      data(rrec(i,16, 6),i=1,2)/9.200e-11,0.7140/
      data(rrec(i,17, 6),i=1,2)/1.198e-10,0.7508/
      data(rrec(i,18, 6),i=1,2)/1.580e-10,0.7900/
      data(rrec(i,19, 6),i=1,2)/2.048e-10,0.8032/
      data(rrec(i,20, 6),i=1,2)/2.600e-10,0.8000/
      data(rrec(i,21, 6),i=1,2)/3.280e-10,0.7990/
      data(rrec(i,22, 6),i=1,2)/3.966e-10,0.7973/
      data(rrec(i,23, 6),i=1,2)/4.760e-10,0.8000/
      data(rrec(i,24, 6),i=1,2)/5.547e-10,0.8027/
      data(rrec(i,25, 6),i=1,2)/6.313e-10,0.8058/
      data(rrec(i,27, 6),i=1,2)/7.503e-10,0.8085/
      data(rrec(i,28, 6),i=1,2)/7.940e-10,0.8080/
      data(rrec(i,29, 6),i=1,2)/8.380e-10,0.8080/
      data(rrec(i,30, 6),i=1,2)/8.810e-10,0.8070/
      data(rrec(i, 7, 7),i=1,2)/4.100e-13,0.6080/
      data(rrec(i, 8, 7),i=1,2)/2.000e-12,0.6460/
      data(rrec(i, 9, 7),i=1,2)/5.231e-12,0.6615/
      data(rrec(i,10, 7),i=1,2)/9.100e-12,0.6680/
      data(rrec(i,11, 7),i=1,2)/1.447e-11,0.6814/
      data(rrec(i,12, 7),i=1,2)/2.300e-11,0.6950/
      data(rrec(i,13, 7),i=1,2)/3.145e-11,0.6915/
      data(rrec(i,14, 7),i=1,2)/4.300e-11,0.6880/
      data(rrec(i,15, 7),i=1,2)/5.659e-11,0.7023/
      data(rrec(i,16, 7),i=1,2)/7.400e-11,0.7160/
      data(rrec(i,17, 7),i=1,2)/9.561e-11,0.7102/
      data(rrec(i,18, 7),i=1,2)/1.230e-10,0.7020/
      data(rrec(i,19, 7),i=1,2)/1.587e-10,0.7105/
      data(rrec(i,20, 7),i=1,2)/2.040e-10,0.7300/
      data(rrec(i,21, 7),i=1,2)/2.630e-10,0.7490/
      data(rrec(i,22, 7),i=1,2)/3.220e-10,0.7683/
      data(rrec(i,23, 7),i=1,2)/3.950e-10,0.7830/
      data(rrec(i,24, 7),i=1,2)/4.671e-10,0.7967/
      data(rrec(i,25, 7),i=1,2)/5.407e-10,0.8058/
      data(rrec(i,27, 7),i=1,2)/6.611e-10,0.8121/
      data(rrec(i,28, 7),i=1,2)/7.080e-10,0.8110/
      data(rrec(i,29, 7),i=1,2)/7.550e-10,0.8100/
      data(rrec(i,30, 7),i=1,2)/8.020e-10,0.8090/
      data(rrec(i, 8, 8),i=1,2)/3.100e-13,0.6780/
      data(rrec(i, 9, 8),i=1,2)/1.344e-12,0.6708/
      data(rrec(i,10, 8),i=1,2)/4.400e-12,0.6750/
      data(rrec(i,11, 8),i=1,2)/7.849e-12,0.6952/
      data(rrec(i,12, 8),i=1,2)/1.400e-11,0.7160/
      data(rrec(i,13, 8),i=1,2)/2.049e-11,0.7090/
      data(rrec(i,14, 8),i=1,2)/3.000e-11,0.7020/
      data(rrec(i,15, 8),i=1,2)/4.125e-11,0.6965/
      data(rrec(i,16, 8),i=1,2)/5.500e-11,0.7110/
      data(rrec(i,17, 8),i=1,2)/7.280e-11,0.7518/
      data(rrec(i,18, 8),i=1,2)/9.550e-11,0.7930/
      data(rrec(i,19, 8),i=1,2)/1.235e-10,0.8052/
      data(rrec(i,20, 8),i=1,2)/1.580e-10,0.8000/
      data(rrec(i,21, 8),i=1,2)/2.060e-10,0.7990/
      data(rrec(i,22, 8),i=1,2)/2.537e-10,0.7977/
      data(rrec(i,23, 8),i=1,2)/3.190e-10,0.8020/
      data(rrec(i,24, 8),i=1,2)/3.844e-10,0.8071/
      data(rrec(i,25, 8),i=1,2)/4.564e-10,0.8124/
      data(rrec(i,27, 8),i=1,2)/5.842e-10,0.8168/
      data(rrec(i,28, 8),i=1,2)/6.380e-10,0.8160/
      data(rrec(i,29, 8),i=1,2)/6.920e-10,0.8150/
      data(rrec(i,30, 8),i=1,2)/7.460e-10,0.8140/
      data(rrec(i, 9, 9),i=1,2)/6.273e-13,0.6798/
      data(rrec(i,10, 9),i=1,2)/1.500e-12,0.6930/
      data(rrec(i,11, 9),i=1,2)/3.399e-12,0.7054/
      data(rrec(i,12, 9),i=1,2)/7.700e-12,0.7180/
      data(rrec(i,13, 9),i=1,2)/1.275e-11,0.7170/
      data(rrec(i,14, 9),i=1,2)/2.110e-11,0.7160/
      data(rrec(i,15, 9),i=1,2)/2.975e-11,0.6945/
      data(rrec(i,16, 9),i=1,2)/4.000e-11,0.6960/
      data(rrec(i,17, 9),i=1,2)/5.281e-11,0.7491/
      data(rrec(i,18, 9),i=1,2)/6.920e-11,0.8110/
      data(rrec(i,19, 9),i=1,2)/9.044e-11,0.8251/
      data(rrec(i,20, 9),i=1,2)/1.180e-10,0.8100/
      data(rrec(i,21, 9),i=1,2)/1.580e-10,0.8040/
      data(rrec(i,22, 9),i=1,2)/1.983e-10,0.7980/
      data(rrec(i,23, 9),i=1,2)/2.570e-10,0.8040/
      data(rrec(i,24, 9),i=1,2)/3.154e-10,0.8101/
      data(rrec(i,25, 9),i=1,2)/3.837e-10,0.8183/
      data(rrec(i,27, 9),i=1,2)/5.147e-10,0.8253/
      data(rrec(i,28, 9),i=1,2)/5.750e-10,0.8240/
      data(rrec(i,29, 9),i=1,2)/6.350e-10,0.8230/
      data(rrec(i,30, 9),i=1,2)/6.960e-10,0.8210/
      data(rrec(i,10,10),i=1,2)/2.200e-13,0.7590/
      data(rrec(i,11,10),i=1,2)/8.775e-13,0.7467/
      data(rrec(i,12,10),i=1,2)/3.500e-12,0.7340/
      data(rrec(i,13,10),i=1,2)/6.481e-12,0.7345/
      data(rrec(i,14,10),i=1,2)/1.200e-11,0.7350/
      data(rrec(i,15,10),i=1,2)/1.834e-11,0.7285/
      data(rrec(i,16,10),i=1,2)/2.700e-11,0.7330/
      data(rrec(i,17,10),i=1,2)/3.711e-11,0.7641/
      data(rrec(i,18,10),i=1,2)/4.900e-11,0.8010/
      data(rrec(i,19,10),i=1,2)/6.444e-11,0.8175/
      data(rrec(i,20,10),i=1,2)/8.510e-11,0.8200/
      data(rrec(i,21,10),i=1,2)/1.170e-10,0.8220/
      data(rrec(i,22,10),i=1,2)/1.494e-10,0.8242/
      data(rrec(i,23,10),i=1,2)/2.010e-10,0.8280/
      data(rrec(i,24,10),i=1,2)/2.525e-10,0.8311/
      data(rrec(i,25,10),i=1,2)/3.177e-10,0.8341/
      data(rrec(i,27,10),i=1,2)/4.552e-10,0.8364/
      data(rrec(i,28,10),i=1,2)/5.250e-10,0.8360/
      data(rrec(i,29,10),i=1,2)/5.950e-10,0.8360/
      data(rrec(i,30,10),i=1,2)/6.650e-10,0.8350/
      data(rrec(i,12,12),i=1,2)/1.400e-13,0.8550/
      data(rrec(i,13,12),i=1,2)/7.197e-13,0.7697/
      data(rrec(i,14,12),i=1,2)/3.700e-12,0.6930/
      data(rrec(i,15,12),i=1,2)/7.980e-12,0.6829/
      data(rrec(i,16,12),i=1,2)/1.200e-11,0.7010/
      data(rrec(i,17,12),i=1,2)/1.800e-11,0.7232/
      data(rrec(i,18,12),i=1,2)/2.690e-11,0.7440/
      data(rrec(i,19,12),i=1,2)/3.748e-11,0.7628/
      data(rrec(i,20,12),i=1,2)/5.040e-11,0.7800/
      data(rrec(i,21,12),i=1,2)/7.240e-11,0.7950/
      data(rrec(i,22,12),i=1,2)/9.440e-11,0.8107/
      data(rrec(i,23,12),i=1,2)/1.350e-10,0.8220/
      data(rrec(i,24,12),i=1,2)/1.751e-10,0.8340/
      data(rrec(i,25,12),i=1,2)/2.298e-10,0.8417/
      data(rrec(i,27,12),i=1,2)/3.461e-10,0.8469/
      data(rrec(i,28,12),i=1,2)/4.030e-10,0.8460/
      data(rrec(i,29,12),i=1,2)/4.600e-10,0.8450/
      data(rrec(i,30,12),i=1,2)/5.170e-10,0.8440/
      data(rrec(i,13,13),i=1,2)/3.980e-13,0.8019/
      data(rrec(i,14,13),i=1,2)/1.000e-12,0.7860/
      data(rrec(i,15,13),i=1,2)/2.558e-12,0.7629/
      data(rrec(i,16,13),i=1,2)/5.700e-12,0.7550/
      data(rrec(i,17,13),i=1,2)/1.011e-11,0.7703/
      data(rrec(i,18,13),i=1,2)/1.580e-11,0.7930/
      data(rrec(i,19,13),i=1,2)/2.448e-11,0.8052/
      data(rrec(i,20,13),i=1,2)/3.760e-11,0.8100/
      data(rrec(i,21,13),i=1,2)/5.870e-11,0.8150/
      data(rrec(i,22,13),i=1,2)/7.972e-11,0.8206/
      data(rrec(i,23,13),i=1,2)/1.130e-10,0.8270/
      data(rrec(i,24,13),i=1,2)/1.470e-10,0.8325/
      data(rrec(i,25,13),i=1,2)/1.908e-10,0.8372/
      data(rrec(i,27,13),i=1,2)/2.976e-10,0.8406/
      data(rrec(i,28,13),i=1,2)/3.630e-10,0.8400/
      data(rrec(i,29,13),i=1,2)/4.280e-10,0.8390/
      data(rrec(i,30,13),i=1,2)/4.940e-10,0.8390/
      data(rrec(i,14,14),i=1,2)/5.900e-13,0.6010/
      data(rrec(i,15,14),i=1,2)/1.294e-12,0.6766/
      data(rrec(i,16,14),i=1,2)/2.700e-12,0.7450/
      data(rrec(i,17,14),i=1,2)/5.165e-12,0.7893/
      data(rrec(i,18,14),i=1,2)/9.120e-12,0.8110/
      data(rrec(i,19,14),i=1,2)/1.513e-11,0.8186/
      data(rrec(i,20,14),i=1,2)/2.400e-11,0.8200/
      data(rrec(i,21,14),i=1,2)/3.960e-11,0.8220/
      data(rrec(i,22,14),i=1,2)/5.518e-11,0.8245/
      data(rrec(i,23,14),i=1,2)/8.370e-11,0.8280/
      data(rrec(i,24,14),i=1,2)/1.123e-10,0.8313/
      data(rrec(i,25,14),i=1,2)/1.525e-10,0.8342/
      data(rrec(i,26,14),i=1,2)/2.000e-10,0.8360/
      data(rrec(i,27,14),i=1,2)/2.537e-10,0.8364/
      data(rrec(i,28,14),i=1,2)/3.160e-10,0.8360/
      data(rrec(i,29,14),i=1,2)/3.780e-10,0.8360/
      data(rrec(i,30,14),i=1,2)/4.410e-10,0.8350/
      data(rrec(i,15,15),i=1,2)/9.761e-13,0.6209/
      data(rrec(i,16,15),i=1,2)/1.800e-12,0.6860/
      data(rrec(i,17,15),i=1,2)/3.320e-12,0.7579/
      data(rrec(i,18,15),i=1,2)/6.030e-12,0.8120/
      data(rrec(i,19,15),i=1,2)/1.063e-11,0.8269/
      data(rrec(i,20,15),i=1,2)/1.800e-11,0.8200/
      data(rrec(i,21,15),i=1,2)/3.130e-11,0.8180/
      data(rrec(i,22,15),i=1,2)/4.451e-11,0.8153/
      data(rrec(i,23,15),i=1,2)/6.830e-11,0.8200/
      data(rrec(i,24,15),i=1,2)/9.206e-11,0.8246/
      data(rrec(i,25,15),i=1,2)/1.250e-10,0.8302/
      data(rrec(i,26,15),i=1,2)/1.640e-10,0.8340/
      data(rrec(i,27,15),i=1,2)/2.093e-10,0.8349/
      data(rrec(i,28,15),i=1,2)/2.630e-10,0.8340/
      data(rrec(i,29,15),i=1,2)/3.170e-10,0.8330/
      data(rrec(i,30,15),i=1,2)/3.700e-10,0.8320/
      data(rrec(i,16,16),i=1,2)/4.100e-13,0.6300/
      data(rrec(i,17,16),i=1,2)/1.248e-12,0.7663/
      data(rrec(i,18,16),i=1,2)/3.230e-12,0.8690/
      data(rrec(i,19,16),i=1,2)/6.384e-12,0.8790/
      data(rrec(i,20,16),i=1,2)/1.070e-11,0.8400/
      data(rrec(i,21,16),i=1,2)/1.920e-11,0.8210/
      data(rrec(i,22,16),i=1,2)/2.765e-11,0.8012/
      data(rrec(i,23,16),i=1,2)/4.650e-11,0.8060/
      data(rrec(i,24,16),i=1,2)/6.539e-11,0.8099/
      data(rrec(i,25,16),i=1,2)/9.539e-11,0.8202/
      data(rrec(i,26,16),i=1,2)/1.330e-10,0.8280/
      data(rrec(i,27,16),i=1,2)/1.769e-10,0.8299/
      data(rrec(i,28,16),i=1,2)/2.290e-10,0.8280/
      data(rrec(i,29,16),i=1,2)/2.810e-10,0.8260/
      data(rrec(i,30,16),i=1,2)/3.330e-10,0.8240/
      data(rrec(i,17,17),i=1,2)/1.010e-12,0.7380/
      data(rrec(i,18,17),i=1,2)/1.950e-12,0.7520/
      data(rrec(i,19,17),i=1,2)/3.766e-12,0.7662/
      data(rrec(i,20,17),i=1,2)/7.080e-12,0.7800/
      data(rrec(i,21,17),i=1,2)/1.430e-11,0.7920/
      data(rrec(i,22,17),i=1,2)/2.152e-11,0.8038/
      data(rrec(i,23,17),i=1,2)/3.740e-11,0.8120/
      data(rrec(i,24,17),i=1,2)/5.335e-11,0.8207/
      data(rrec(i,25,17),i=1,2)/7.807e-11,0.8260/
      data(rrec(i,26,17),i=1,2)/1.090e-10,0.8290/
      data(rrec(i,27,17),i=1,2)/1.459e-10,0.8296/
      data(rrec(i,28,17),i=1,2)/1.910e-10,0.8290/
      data(rrec(i,29,17),i=1,2)/2.360e-10,0.8280/
      data(rrec(i,30,17),i=1,2)/2.810e-10,0.8280/
      data(rrec(i,18,18),i=1,2)/3.770e-13,0.6510/
      data(rrec(i,19,18),i=1,2)/1.304e-12,0.6753/
      data(rrec(i,20,18),i=1,2)/3.960e-12,0.7000/
      data(rrec(i,21,18),i=1,2)/1.130e-11,0.7240/
      data(rrec(i,22,18),i=1,2)/1.857e-11,0.7484/
      data(rrec(i,23,18),i=1,2)/3.170e-11,0.7680/
      data(rrec(i,24,18),i=1,2)/4.479e-11,0.7883/
      data(rrec(i,25,18),i=1,2)/6.106e-11,0.8020/
      data(rrec(i,26,18),i=1,2)/8.130e-11,0.8100/
      data(rrec(i,27,18),i=1,2)/1.098e-10,0.8118/
      data(rrec(i,28,18),i=1,2)/1.500e-10,0.8100/
      data(rrec(i,29,18),i=1,2)/1.900e-10,0.8080/
      data(rrec(i,30,18),i=1,2)/2.300e-10,0.8060/
      data(rrec(i,19,19),i=1,2)/2.762e-13,0.8023/
      data(rrec(i,20,19),i=1,2)/6.780e-13,0.8000/
      data(rrec(i,21,19),i=1,2)/2.330e-12,0.7980/
      data(rrec(i,22,19),i=1,2)/3.983e-12,0.7955/
      data(rrec(i,23,19),i=1,2)/1.150e-11,0.7940/
      data(rrec(i,24,19),i=1,2)/1.906e-11,0.7919/
      data(rrec(i,25,19),i=1,2)/3.620e-11,0.7907/
      data(rrec(i,26,19),i=1,2)/6.050e-11,0.7900/
      data(rrec(i,27,19),i=1,2)/8.818e-11,0.7898/
      data(rrec(i,28,19),i=1,2)/1.190e-10,0.7900/
      data(rrec(i,29,19),i=1,2)/1.500e-10,0.7900/
      data(rrec(i,30,19),i=1,2)/1.810e-10,0.7900/
      data(rrec(i,20,20),i=1,2)/1.120e-13,0.9000/
      data(rrec(i,21,20),i=1,2)/6.540e-13,0.8670/
      data(rrec(i,22,20),i=1,2)/1.196e-12,0.8344/
      data(rrec(i,23,20),i=1,2)/5.330e-12,0.8090/
      data(rrec(i,24,20),i=1,2)/9.471e-12,0.7846/
      data(rrec(i,25,20),i=1,2)/2.169e-11,0.7683/
      data(rrec(i,26,20),i=1,2)/4.120e-11,0.7590/
      data(rrec(i,27,20),i=1,2)/6.409e-11,0.7570/
      data(rrec(i,28,20),i=1,2)/8.910e-11,0.7590/
      data(rrec(i,29,20),i=1,2)/1.140e-10,0.7610/
      data(rrec(i,30,20),i=1,2)/1.390e-10,0.7630/
      data(rrec(i,21,21),i=1,2)/1.170e-13,0.8980/
      data(rrec(i,22,21),i=1,2)/5.330e-12,0.8640/
      data(rrec(i,23,21),i=1,2)/1.060e-11,0.8300/
      data(rrec(i,24,21),i=1,2)/1.580e-11,0.7960/
      data(rrec(i,25,21),i=1,2)/2.100e-11,0.7620/
      data(rrec(i,26,21),i=1,2)/2.620e-11,0.7280/
      data(rrec(i,27,21),i=1,2)/2.822e-11,0.7280/
      data(rrec(i,28,21),i=1,2)/3.040e-11,0.7280/
      data(rrec(i,29,21),i=1,2)/3.260e-11,0.7280/
      data(rrec(i,30,21),i=1,2)/3.480e-11,0.7280/
      data(rrec(i,22,22),i=1,2)/1.220e-13,0.8970/
      data(rrec(i,23,22),i=1,2)/3.870e-12,0.8480/
      data(rrec(i,24,22),i=1,2)/7.610e-12,0.7980/
      data(rrec(i,25,22),i=1,2)/1.140e-11,0.7480/
      data(rrec(i,26,22),i=1,2)/1.510e-11,0.6990/
      data(rrec(i,27,22),i=1,2)/1.626e-11,0.6990/
      data(rrec(i,28,22),i=1,2)/1.750e-11,0.6990/
      data(rrec(i,29,22),i=1,2)/1.870e-11,0.6990/
      data(rrec(i,30,22),i=1,2)/2.000e-11,0.6990/
      data(rrec(i,23,23),i=1,2)/1.270e-13,0.8950/
      data(rrec(i,24,23),i=1,2)/2.680e-12,0.8240/
      data(rrec(i,25,23),i=1,2)/5.240e-12,0.7530/
      data(rrec(i,26,23),i=1,2)/7.800e-12,0.6820/
      data(rrec(i,27,23),i=1,2)/8.402e-12,0.6820/
      data(rrec(i,28,23),i=1,2)/9.050e-12,0.6820/
      data(rrec(i,29,23),i=1,2)/9.700e-12,0.6820/
      data(rrec(i,30,23),i=1,2)/1.030e-11,0.6820/
      data(rrec(i,24,24),i=1,2)/1.320e-13,0.8940/
      data(rrec(i,25,24),i=1,2)/1.730e-12,0.8200/
      data(rrec(i,26,24),i=1,2)/3.320e-12,0.7460/
      data(rrec(i,27,24),i=1,2)/3.575e-12,0.7460/
      data(rrec(i,28,24),i=1,2)/3.580e-12,0.7460/
      data(rrec(i,29,24),i=1,2)/3.580e-12,0.7460/
      data(rrec(i,30,24),i=1,2)/3.590e-12,0.7460/
      data(rrec(i,25,25),i=1,2)/1.370e-13,0.8920/
      data(rrec(i,26,25),i=1,2)/1.020e-12,0.8430/
      data(rrec(i,27,25),i=1,2)/1.278e-12,0.7682/
      data(rrec(i,28,25),i=1,2)/1.600e-12,0.7000/
      data(rrec(i,29,25),i=1,2)/1.920e-12,0.7000/
      data(rrec(i,30,25),i=1,2)/2.240e-12,0.7000/
      data(rrec(i,26,26),i=1,2)/1.420e-13,0.8910/
      data(rrec(i,27,26),i=1,2)/4.459e-13,0.7897/
      data(rrec(i,28,26),i=1,2)/1.400e-12,0.7000/
      data(rrec(i,29,26),i=1,2)/1.500e-12,0.7000/
      data(rrec(i,30,26),i=1,2)/1.600e-12,0.7000/
      data(rrec(i,27,27),i=1,2)/2.510e-13,0.7950/
      data(rrec(i,28,27),i=1,2)/1.000e-12,0.7000/
      data(rrec(i,29,27),i=1,2)/1.000e-12,0.7000/
      data(rrec(i,30,27),i=1,2)/1.100e-12,0.7000/
      data(rrec(i,28,28),i=1,2)/3.600e-13,0.7000/
      data(rrec(i,29,28),i=1,2)/3.600e-13,0.7000/
      data(rrec(i,30,28),i=1,2)/3.600e-13,0.7000/
      data(rrec(i,29,29),i=1,2)/3.600e-13,0.7000/
      data(rrec(i,30,29),i=1,2)/3.600e-13,0.7000/
      data(rrec(i,30,30),i=1,2)/3.600e-13,0.7000/
      data(rnew(i, 1, 1),i=1,4)/7.982e-11,0.7480,3.148e+00,7.036e+05/
      data(rnew(i, 2, 1),i=1,4)/1.891e-10,0.7524,9.370e+00,2.774e+06/
      data(rnew(i, 3, 1),i=1,4)/3.039e-10,0.7539,1.871e+01,6.209e+06/
      data(rnew(i, 4, 1),i=1,4)/4.290e-10,0.7557,3.000e+01,1.093e+07/
      data(rnew(i, 5, 1),i=1,4)/5.437e-10,0.7560,4.576e+01,1.706e+07/
      data(rnew(i, 6, 1),i=1,4)/6.556e-10,0.7567,6.523e+01,2.446e+07/
      data(rnew(i, 7, 1),i=1,4)/7.586e-10,0.7563,9.015e+01,3.338e+07/
      data(rnew(i, 8, 1),i=1,4)/8.616e-10,0.7563,1.191e+02,4.352e+07/
      data(rnew(i, 9, 1),i=1,4)/9.712e-10,0.7566,1.499e+02,5.498e+07/
      data(rnew(i,10, 1),i=1,4)/1.085e-09,0.7570,1.834e+02,6.776e+07/
      data(rnew(i,11, 1),i=1,4)/1.163e-09,0.7558,2.328e+02,8.262e+07/
      data(rnew(i,12, 1),i=1,4)/1.317e-09,0.7574,2.585e+02,9.769e+07/
      data(rnew(i,13, 1),i=1,4)/1.419e-09,0.7578,3.057e+02,1.143e+08/
      data(rnew(i,14, 1),i=1,4)/1.517e-09,0.7574,3.601e+02,1.329e+08/
      data(rnew(i,15, 1),i=1,4)/1.586e-09,0.7560,4.327e+02,1.534e+08/
      data(rnew(i,16, 1),i=1,4)/1.729e-09,0.7568,4.725e+02,1.746e+08/
      data(rnew(i,17, 1),i=1,4)/1.791e-09,0.7565,5.591e+02,1.972e+08/
      data(rnew(i,18, 1),i=1,4)/1.913e-09,0.7567,6.175e+02,2.212e+08/
      data(rnew(i,19, 1),i=1,4)/2.033e-09,0.7569,6.797e+02,2.463e+08/
      data(rnew(i,20, 1),i=1,4)/2.129e-09,0.7570,7.591e+02,2.739e+08/
      data(rnew(i,21, 1),i=1,4)/2.262e-09,0.7578,8.186e+02,3.000e+08/
      data(rnew(i,22, 1),i=1,4)/2.370e-09,0.7574,9.002e+02,3.307e+08/
      data(rnew(i,23, 1),i=1,4)/2.415e-09,0.7565,1.032e+03,3.635e+08/
      data(rnew(i,24, 1),i=1,4)/2.537e-09,0.7571,1.108e+03,3.954e+08/
      data(rnew(i,25, 1),i=1,4)/2.618e-09,0.7565,1.225e+03,4.307e+08/
      data(rnew(i,26, 1),i=1,4)/2.735e-09,0.7568,1.314e+03,4.659e+08/
      data(rnew(i,27, 1),i=1,4)/2.809e-09,0.7565,1.444e+03,5.042e+08/
      data(rnew(i,28, 1),i=1,4)/3.002e-09,0.7581,1.467e+03,5.409e+08/
      data(rnew(i,29, 1),i=1,4)/3.022e-09,0.7564,1.666e+03,5.855e+08/
      data(rnew(i,30, 1),i=1,4)/3.127e-09,0.7567,1.779e+03,6.246e+08/
      data(rnew(i, 2, 2),i=1,4)/9.356e-10,0.7892,4.266e-02,4.677e+06/
      data(rnew(i, 3, 2),i=1,4)/1.112e-10,0.6926,2.437e+01,8.323e+06/
      data(rnew(i, 4, 2),i=1,4)/1.317e-10,0.6691,8.473e+01,1.412e+07/
      data(rnew(i, 5, 2),i=1,4)/1.922e-10,0.6717,1.272e+02,1.975e+07/
      data(rnew(i, 6, 2),i=1,4)/2.765e-10,0.6858,1.535e+02,2.556e+07/
      data(rnew(i, 7, 2),i=1,4)/3.910e-10,0.6988,1.611e+02,3.271e+07/
      data(rnew(i, 8, 2),i=1,4)/4.897e-10,0.7048,1.906e+02,4.093e+07/
      data(rnew(i, 9, 2),i=1,4)/5.602e-10,0.7052,2.476e+02,5.077e+07/
      data(rnew(i,10, 2),i=1,4)/6.161e-10,0.7029,3.274e+02,6.243e+07/
      data(rnew(i,11, 2),i=1,4)/6.833e-10,0.7018,4.060e+02,7.491e+07/
      data(rnew(i,12, 2),i=1,4)/7.510e-10,0.7020,4.921e+02,8.643e+07/
      data(rnew(i,13, 2),i=1,4)/8.182e-10,0.7008,5.875e+02,1.007e+08/
      data(rnew(i,14, 2),i=1,4)/8.722e-10,0.6996,7.098e+02,1.155e+08/
      data(rnew(i,15, 2),i=1,4)/9.142e-10,0.6961,8.682e+02,1.335e+08/
      data(rnew(i,16, 2),i=1,4)/9.692e-10,0.6945,1.017e+03,1.517e+08/
      data(rnew(i,17, 2),i=1,4)/1.021e-09,0.6932,1.184e+03,1.695e+08/
      data(rnew(i,18, 2),i=1,4)/1.087e-09,0.6936,1.329e+03,1.880e+08/
      data(rnew(i,19, 2),i=1,4)/1.145e-09,0.6921,1.503e+03,2.098e+08/
      data(rnew(i,20, 2),i=1,4)/1.179e-09,0.6893,1.757e+03,2.344e+08/
      data(rnew(i,21, 2),i=1,4)/1.265e-09,0.6902,1.877e+03,2.555e+08/
      data(rnew(i,22, 2),i=1,4)/1.322e-09,0.6885,2.092e+03,2.829e+08/
      data(rnew(i,23, 2),i=1,4)/1.375e-09,0.6885,2.321e+03,3.056e+08/
      data(rnew(i,24, 2),i=1,4)/1.422e-09,0.6874,2.589e+03,3.336e+08/
      data(rnew(i,25, 2),i=1,4)/1.488e-09,0.6867,2.802e+03,3.623e+08/
      data(rnew(i,26, 2),i=1,4)/1.542e-09,0.6859,3.073e+03,3.926e+08/
      data(rnew(i,27, 2),i=1,4)/1.589e-09,0.6846,3.373e+03,4.267e+08/
      data(rnew(i,28, 2),i=1,4)/1.676e-09,0.6861,3.530e+03,4.538e+08/
      data(rnew(i,29, 2),i=1,4)/1.686e-09,0.6824,4.031e+03,4.948e+08/
      data(rnew(i,30, 2),i=1,4)/1.758e-09,0.6834,4.254e+03,5.258e+08/
      data(rnew(i, 3, 3),i=1,4)/1.036e-11,0.3880,1.077e+02,1.177e+07/
      data(rnew(i, 4, 3),i=1,4)/2.338e-11,0.4211,3.647e+02,1.215e+07/
      data(rnew(i, 5, 3),i=1,4)/4.487e-11,0.4644,5.371e+02,1.465e+07/
      data(rnew(i, 6, 3),i=1,4)/8.540e-11,0.5247,5.014e+02,1.479e+07/
      data(rnew(i, 7, 3),i=1,4)/1.169e-10,0.5470,6.793e+02,1.650e+07/
      data(rnew(i, 8, 3),i=1,4)/2.053e-10,0.6019,4.772e+02,1.711e+07/
      data(rnew(i, 9, 3),i=1,4)/2.739e-10,0.6188,5.033e+02,2.064e+07/
      data(rnew(i,10, 3),i=1,4)/3.200e-10,0.6198,6.329e+02,2.616e+07/
      data(rnew(i,11, 3),i=1,4)/3.873e-10,0.6295,7.000e+02,2.989e+07/
      data(rnew(i,12, 3),i=1,4)/4.284e-10,0.6287,8.748e+02,3.586e+07/
      data(rnew(i,13, 3),i=1,4)/4.881e-10,0.6326,9.941e+02,4.085e+07/
      data(rnew(i,14, 3),i=1,4)/5.373e-10,0.6337,1.164e+03,4.677e+07/
      data(rnew(i,15, 3),i=1,4)/5.876e-10,0.6354,1.341e+03,5.292e+07/
      data(rnew(i,16, 3),i=1,4)/6.571e-10,0.6400,1.452e+03,5.796e+07/
      data(rnew(i,17, 3),i=1,4)/7.076e-10,0.6397,1.653e+03,6.555e+07/
      data(rnew(i,18, 3),i=1,4)/7.538e-10,0.6388,1.889e+03,7.306e+07/
      data(rnew(i,19, 3),i=1,4)/8.182e-10,0.6411,2.044e+03,8.057e+07/
      data(rnew(i,20, 3),i=1,4)/8.577e-10,0.6403,2.334e+03,8.850e+07/
      data(rnew(i,21, 3),i=1,4)/9.162e-10,0.6413,2.543e+03,9.690e+07/
      data(rnew(i,22, 3),i=1,4)/9.844e-10,0.6440,2.708e+03,1.044e+08/
      data(rnew(i,23, 3),i=1,4)/1.020e-09,0.6427,3.057e+03,1.140e+08/
      data(rnew(i,24, 3),i=1,4)/1.091e-09,0.6445,3.225e+03,1.229e+08/
      data(rnew(i,25, 3),i=1,4)/1.151e-09,0.6451,3.461e+03,1.334e+08/
      data(rnew(i,26, 3),i=1,4)/1.198e-09,0.6443,3.789e+03,1.437e+08/
      data(rnew(i,27, 3),i=1,4)/1.211e-09,0.6406,4.357e+03,1.572e+08/
      data(rnew(i,28, 3),i=1,4)/1.288e-09,0.6440,4.506e+03,1.651e+08/
      data(rnew(i,29, 3),i=1,4)/1.372e-09,0.6472,4.627e+03,1.740e+08/
      data(rnew(i,30, 3),i=1,4)/1.412e-09,0.6454,5.053e+03,1.891e+08/
      data(rnew(i,11,11),i=1,4)/5.641e-12,0.1749,3.077e+02,2.617e+06/
      data(rnew(i,12,11),i=1,4)/1.920e-11,0.3028,4.849e+02,5.890e+06/
      data(rnew(i,13,11),i=1,4)/3.753e-11,0.3585,6.848e+02,9.035e+06/
      data(rnew(i,14,11),i=1,4)/5.942e-11,0.3930,8.962e+02,1.213e+07/
      data(rnew(i,15,11),i=1,4)/1.721e-10,0.5429,2.848e+02,3.975e+07/
      data(rnew(i,16,11),i=1,4)/3.502e-10,0.6266,1.532e+02,1.755e+07/
      data(rnew(i,17,11),i=1,4)/2.502e-10,0.5580,5.303e+02,4.558e+07/
      data(rnew(i,18,11),i=1,4)/2.862e-10,0.5621,7.002e+02,4.885e+07/
      data(rnew(i,19,11),i=1,4)/2.757e-10,0.5364,1.204e+03,7.013e+07/
      data(rnew(i,20,11),i=1,4)/5.273e-10,0.6281,5.329e+02,3.188e+07/
      data(rnew(i,21,11),i=1,4)/3.890e-10,0.5645,1.391e+03,6.295e+07/
      data(rnew(i,22,11),i=1,4)/4.207e-10,0.5646,1.688e+03,6.872e+07/
      data(rnew(i,23,11),i=1,4)/4.605e-10,0.5659,1.949e+03,7.419e+07/
      data(rnew(i,24,11),i=1,4)/4.975e-10,0.5655,2.257e+03,8.072e+07/
      data(rnew(i,25,11),i=1,4)/5.349e-10,0.5658,2.577e+03,8.710e+07/
      data(rnew(i,26,11),i=1,4)/7.688e-10,0.6173,1.653e+03,6.161e+07/
      data(rnew(i,27,11),i=1,4)/5.850e-10,0.5598,3.538e+03,1.052e+08/
      data(rnew(i,28,11),i=1,4)/6.347e-10,0.5631,3.780e+03,1.116e+08/
      data(rnew(i,29,11),i=1,4)/6.619e-10,0.5602,4.322e+03,1.210e+08/
      data(rnew(i,30,11),i=1,4)/7.002e-10,0.5612,4.726e+03,1.287e+08/
      data(rnew(i, 6, 4),i=1,4)/2.020E-09,0.7798,6.690E-01,2.425E+06/
      data(rnew(i, 7, 4),i=1,4)/1.595E-11,0.3529,9.870E+03,2.584E+07/
      data(rnew(i, 8, 4),i=1,4)/2.008E-11,0.3567,1.520E+04,3.843E+07/
      data(rnew(i,10, 4),i=1,4)/2.793E-11,0.3533,3.017E+04,7.872E+07/
      data(rnew(i, 6, 5),i=1,4)/8.577E-10,0.7837,7.286E-01,1.140E+07/
      data(rnew(i, 7, 5),i=1,4)/7.039E-10,0.8607,2.203E+00,3.029E+06/
      data(rnew(i, 8, 5),i=1,4)/1.542E-10,0.6712,1.775E+02,1.535E+08/
      data(rnew(i,10, 5),i=1,4)/2.515E-10,0.7011,3.028E+02,8.903E+06/
      data(rnew(i, 6, 6),i=1,4)/7.651E-09,0.8027,1.193E-03,9.334E+12/
      data(rnew(i, 7, 6),i=1,4)/5.989E-10,0.7560,1.377E+00,1.517E+09/
      data(rnew(i, 8, 6),i=1,4)/3.672E-09,0.7676,2.900E-01,8.521E+07/
      data(rnew(i,10, 6),i=1,4)/9.353E-11,0.6270,9.031E+02,2.387E+07/
      data(rnew(i, 7, 7),i=1,4)/1.243E-08,0.7022,1.136E-03,1.015E+13/
      data(rnew(i, 8, 7),i=1,4)/1.816E-08,0.7170,6.717E-03,3.286E+12/
      data(rnew(i,10, 7),i=1,4)/4.227E-11,0.5395,1.687E+03,1.491E+17/
      data(rnew(i, 8, 8),i=1,4)/1.341E-10,0.6159,1.673E+00,6.366E+16/
      data(rnew(i,10, 8),i=1,4)/9.563E-12,0.3067,9.768E+03,4.851E+17/
      data(rnew(i,10, 9),i=1,4)/5.417E-08,0.6930,1.179E-03,1.060E+07/
      data(rnew(i,10,10),i=1,4)/5.023E-12,0.2420,3.181E+02,1.450E+18/
      data(rnew(i,26,12),i=1,4)/8.110E-10,0.5442,1.755E+03,6.799E+07/ 
      data(rnew(i,26,13),i=1,4)/6.967E-10,0.5602,1.727E+03,5.618E+07/ 
      data(rnew(i,26,14),i=1,4)/3.236E-08,0.3247,2.338E+01,8.337E+12/
      data(rnew(i,26,15),i=1,4)/2.664E-08,0.3285,2.297E+01,6.672E+12/
      data(rnew(i,26,16),i=1,4)/2.165E-08,0.3403,2.195E+01,6.383E+12/
      data(rnew(i,26,17),i=1,4)/2.460E-08,0.3387,1.487E+01,5.228E+12/
      data(rnew(i,26,18),i=1,4)/1.907E-08,0.3768,1.216E+01,5.431E+12/
      data(rnew(i,26,19),i=1,4)/1.439E-08,0.4170,1.006E+01,4.898E+12/
      data(rnew(i,26,20),i=1,4)/1.184E-08,0.4798,5.883E+00,2.582E+12/
      data(rnew(i,26,21),i=1,4)/1.036E-08,0.5428,2.743E+00,1.014E+12/
      data(rnew(i,26,22),i=1,4)/8.288E-09,0.6012,1.216E+00,1.182E+12/
      data(rnew(i,26,23),i=1,4)/6.330E-09,0.6355,5.457E-01,8.545E+11/
      data(rnew(i,26,24),i=1,4)/5.422E-09,0.5067,4.998E-01,8.079E+11/
      data(rnew(i,26,25),i=1,4)/6.076E-09,0.3112,3.401E-01,1.960E+12/
      data(rnew(i,26,26),i=1,4)/8.945E-09,0.2156,4.184E-02,5.353E+13/
      data(fe(1,i),i=4,13)/4.33e-10,3.91e-10,3.49e-10,3.16e-10,
     &2.96e-10,2.59e-10,2.24e-10,1.91e-10,1.68e-10,1.46e-10/
      data(fe(2,i),i=4,13)/0.531,0.523,0.521,0.534,
     &0.557,0.567,0.579,0.601,0.602,0.597/
      data(fe(3,i),i=4,13)/5.77e-02,6.15e-02,6.22e-02,6.02e-02,
     &5.79e-02,5.65e-02,5.49e-02,5.10e-02,5.07e-02,5.22e-02/
      end
