******************************************************************************
      real function TotalPressure()
      implicit none
*determine the gas and line radiation pressures for current conditions
      include "amu.par"
      include "bltzman.par"
      include "nta.par"
      include "limelm.par"
      include "ipLnArry.par"
      include "nwindline.par"
      include "prdcap.com"
      include "radpon.com"
      include "prad.com"
      include "iprdmx.com"
      include "IterCnt.com"
      include "phycon.com"
      include "h.com"
      include "he.com"
      include "hmi.com"
      include "densty.com"
      include "conprs.com"
      include "collid.com"
      include "pinteg.com"
      include "hvmolEXP.com"
      include "totnuc.com"
      include "IonFracs.com"
      include "AtomcWgt.com"
      include "TLineARR.com"
      include "WindData.com"
*
*     local variables
      real pmx
      real WidthLine , RadPres1, HHeLines
      integer i,ip
*
*     function TotalPressure - evaluate total pressure
*     this function has a single dummy argument
*     this function evaluates the following
*     TotalPressure - gas and radiation pressure, dynes/cm^2
*     GasPres gas pressure, same units
*
*     HDEN is defined as total hydrogen nuclei density; all forms
*     present abarb with carbon monoxide
*
*     TOTNUC is total number of nuclei and molecules
*     nelem,0 is abundance of nelem
      totnuc = 0.
      do i=1,limelm
        totnuc = totnuc + xIonFracs(i,0)
      end do
*
*      add on molecules
       totnuc = totnuc +
     1 htwo + h2plus + hminus + ch + chp +
     2 oh + ohp + otwo + ctwo + co + cop + h2o + h2op + o2p + c2p +
     3 h3p + h3op + ch2p + ch2 + ch3 + h3plus
*
*     pden is the total number of particles per unit vol
      pden = eden + totnuc
*
*     this is total neutral particle density for collisional ionization
      CollidDensity = 0.
      do i=1,limelm
        CollidDensity = CollidDensity + xIonFracs(i,1)
      end do
*
      CollidDensity = CollidDensity + h2plus + hminus + ch + chp +
     2 oh + ohp + otwo + ctwo + co + cop + h2o + h2op + o2p + c2p +
     3 h3p + h3op + ch2p + ch2 + ch3 + h3plus + 2.*htwo 
*
*     gas pressure
      GasPres = pden * te * Boltzmann
*
*     WMOLE is molecular weight, amu per particle
      wmole = 0.
      do i=1,limelm
        wmole = wmole + xIonFracs(i,0)*AtomicWeight(i)
      end do
*
      wmole = wmole +  ch*13. + chp*13. + oh*17. + ohp*17. + otwo*32. +
     3 ctwo*24. + co*28. + cop*28. + h2o*18. + h2op*18. + o2p*32. +
     4 c2p*24. + h3p*3. + h3op*19. + ch2p*14. + ch2*14. + ch3*15.
*
      wmole = wmole / pden
*
*     xMassDensity is grams per cc
      xMassDensity = wmole * amu * pden
*
*     RadPres is pressure due to lines, lgRadPresON turns off or on
      RadPres = 0.
      pmx = 0.
*     find max rad pressure even if capped
*     lgRadPrsON is turned off by NO RADIATION PRESSURE command
      if( lgRadPrsON ) then
*       plines(1)=l-alpha,          in hlevel(ionize)
*       plines(2) = hign n lyman ;   plines(3)=excit h lines iN HLEVEL
*       plines(4) = he i 10830
*       plines(5)= HeII 304 plines(11)=HeI La (in helium) 
*       plines(6)= HeI 584
*
*       compute radiation pressure due to special H and He lines
        HHeLines = 0.
        do i=1,20
          if( plines(i).gt.pmx ) then
            pmx = plines(i)
            ip = i
          endif
          HHeLines = HHeLines + plines(i)
        end do
*
        RadPres = HHeLines
*
*       line radiation pressure from large set of level 1 lines
        do i=1,nTauLines
          if( TauLines(ipLnPopu,i).gt.1e-30 ) then
            RadPres1 = 5.551e-2*((TauLines(ipLnEnrWN,i)/1.e6)**4)*
     1      ( TauLines(ipLnPopu,i) / TauLines(ipLnGu,i) ) /
     2      ( TauLines(ipLnPopl,i) / TauLines(ipLnGl,i) ) *
     2      WidthLine(TauLines(1,i)) * 2.
            RadPres = RadPres + RadPres1
          endif
        end do
        do i=1,NWINDLINE*nWindOn
          if( WindLine(ipLnPopu,i).gt.1e-30 ) then
            RadPres1 = 5.551e-2*((WindLine(ipLnEnrWN,i)/1.e6)**4)*
     1      ( WindLine(ipLnPopu,i) / WindLine(ipLnGu,i) ) /
     2      ( WindLine(ipLnPopl,i) / WindLine(ipLnGl,i) ) *
     2      WidthLine(WindLine(1,i)) * 2.
            RadPres = RadPres + RadPres1
          endif
        end do
*       call broken
*       everything but Lya
*       write(66,'(1p,2e10.2)') HHeLines , RadPres
      endif
*
*     PBETA is ratio of radiation to gas + continuum pressure
      if( lgConPres ) then
*       this includes integrated incident continuum
        pbeta = RadPres / ( GasPres + pinteg )
      else
*       this does not
        pbeta = RadPres / GasPres
      endif
*
*     stop model from running away on first iteration, when line optical
*     depths are not defined correctly anyway.
*     if( iter.le.itermx .and. RadPres.ge.GasPres ) then
*     >>chng 97 july 23, only cap radiation pressure on first iteration
      if( iter.le.1 .and. RadPres.ge.GasPres ) then
        RadBetaMax = max( RadBetaMax , pbeta )
*       stop RadPres from exceeding the gas pressure on first iteration
        RadPres = min( RadPres , GasPres )
        lgPradCap = .true.
      endif
*
      if( lgRadPresON ) then
        TotalPressure = GasPres + RadPres
      else
        TotalPressure = GasPres
      endif
*
      if( pbeta.ge.RadBetaMax ) then
        RadBetaMax = pbeta
        iprdmx = ip
      endif
*
*     remember highest pressure anywhere
      PresMax = max( PresMax , TotalPressure )
*
      end
